AnalysisArtifactProvenance class

Provenance metadata for an analysis artifact.

Constructors

AnalysisArtifactProvenance({required String version, List<String> tags = const [], required DateTime createdAt, String? sourceUri, String? sourceQuery, AnalysisTimeRange? inputRange, required String specId, required String specVersion})
const
AnalysisArtifactProvenance.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

createdAt DateTime
Timestamp when the artifact was created.
final
hashCode int
The hash code for this object.
no setterinherited
inputRange AnalysisTimeRange?
Time range of the input data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceQuery String?
Query used to produce this artifact.
final
sourceUri String?
URI of the data source that produced this artifact.
final
specId String
Identifier of the spec that produced this artifact.
final
specVersion String
Version of the spec that produced this artifact.
final
tags List<String>
Tags for categorization.
final
version String
Version of the artifact.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited