AnalysisArtifactType enum

Type of analysis artifact produced.

Inheritance
Available extensions

Values

metric → const AnalysisArtifactType

Single numeric metric value.

series → const AnalysisArtifactType

Time-series data points.

table → const AnalysisArtifactType

Tabular data (rows and columns).

chart → const AnalysisArtifactType

Chart with axes and series.

summary → const AnalysisArtifactType

Textual summary with evidence links.

alert → const AnalysisArtifactType

Alert rule definition.

model → const AnalysisArtifactType

Trained or fitted model.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) AnalysisArtifactType
Parse from string with safe default.

Constants

values → const List<AnalysisArtifactType>
A constant List of the values in this enum, in order of their declaration.