AnalysisAxisMeta class

Axis metadata for chart artifacts.

Constructors

AnalysisAxisMeta({required String label, required String type, dynamic min, dynamic max})
Cannot be const due to dynamic fields.
AnalysisAxisMeta.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Axis label text.
final
max → dynamic
Maximum axis value.
final
min → dynamic
Minimum axis value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Axis scale type (linear, logarithmic, time, category).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited