AnalysisError class

Error that occurred during analysis execution.

Constructors

AnalysisError({required String code, required String message, Map<String, dynamic>? details, String? step, DateTime? timestamp})
Cannot be const due to Map<String, dynamic> field.
AnalysisError.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

code String
Error code (e.g., source.unavailable, transform.failed).
final
details Map<String, dynamic>?
Additional error details.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step String?
Name of the step where the error occurred.
final
timestamp DateTime?
Timestamp when the error occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited