AnalysisFunctionInfo class

Information about a registered analysis function.

Constructors

AnalysisFunctionInfo({required String functionName, required String description, Map<String, AnalysisParameterSchema> parameters = const {}, List<String> supportedDataTypes = const [], String? plugin, String? specVersionRange})
AnalysisFunctionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

description String
Human-readable description.
final
functionName String
Function name (e.g., descriptive_stats, anomaly_detect).
final
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, AnalysisParameterSchema>
Parameter schemas keyed by parameter name.
final
plugin String?
Plugin identifier, if external.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specVersionRange String?
Spec version range this function supports.
final
supportedDataTypes List<String>
Supported data types (numeric, temporal, categorical, event).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited