AnalysisFunctionResult class

Result from executing an analysis function.

Constructors

AnalysisFunctionResult({required String functionName, required Map<String, dynamic> results, required Duration executionTime, Map<String, dynamic>? metadata})
AnalysisFunctionResult.fromJson(Map<String, dynamic> json)
factory

Properties

executionTime Duration
Execution time.
final
functionName String
Function that was executed.
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
Additional metadata.
final
results Map<String, dynamic>
Result data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited