AnalysisJobLog class

Log entry for an analysis job step execution.

Constructors

AnalysisJobLog({required String step, required DateTime timestamp, required int inputSize, required int outputSize, required Duration executionTime})
Cannot be const due to Duration field.
AnalysisJobLog.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

executionTime Duration
Wall-clock execution time for the step.
final
hashCode int
The hash code for this object.
no setterinherited
inputSize int
Number of input records processed.
final
outputSize int
Number of output records produced.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step String
Name of the step that produced this log entry.
final
timestamp DateTime
Timestamp when the step completed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited