AnalysisParameterSchema class
Schema for a function parameter.
Constructors
- AnalysisParameterSchema({required String name, required String type, dynamic defaultValue, String? description, dynamic min, dynamic max})
-
AnalysisParameterSchema.fromJson(Map<
String, dynamic> json) -
factory
Properties
- defaultValue → dynamic
-
Default value.
final
- description → String?
-
Description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → dynamic
-
Maximum value constraint.
final
- min → dynamic
-
Minimum value constraint.
final
- name → String
-
Parameter name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Parameter type (int, double, string, boolean, array).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited