AnalysisSourceSchema class

Schema describing the structure of an analysis input source.

Constructors

AnalysisSourceSchema({required List<AnalysisColumnInfo> columns, String? timestampField})
const
AnalysisSourceSchema.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

columns List<AnalysisColumnInfo>
Column definitions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampField String?
Name of the timestamp field, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited