AppliedIntervention class

Individual intervention applied during pipeline processing.

Annotations
  • @immutable

Constructors

AppliedIntervention({required String id, required InterventionType type, required String description, required String rationale, String? ethosComponentId, Map<String, dynamic>? before, Map<String, dynamic>? after})
const
AppliedIntervention.fromJson(Map<String, dynamic> json)
factory

Properties

after Map<String, dynamic>?
State after intervention.
final
before Map<String, dynamic>?
State before intervention.
final
description String
What was done.
final
ethosComponentId String?
Which value/prohibition/criterion triggered this.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier.
final
rationale String
Why (linked to ethos component).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InterventionType
Type of intervention.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited