ApprovalRecord class

Historical approval record.

Constructors

ApprovalRecord({required String approvalId, required ApprovalRequest request, required ApprovalResult result, required DateTime createdAt, DateTime? resolvedAt})
const
ApprovalRecord.fromJson(Map<String, dynamic> json)
factory

Properties

approvalId String
Approval ID.
final
createdAt DateTime
When the request was created.
final
hashCode int
The hash code for this object.
no setterinherited
request ApprovalRequest
Original request.
final
resolvedAt DateTime?
When it was resolved (if resolved).
final
result ApprovalResult
Final result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited