ApprovalStatus enum

Status of an approval request.

Inheritance
Available extensions

Values

pending → const ApprovalStatus

Waiting for approval.

approved → const ApprovalStatus

Approved.

rejected → const ApprovalStatus

Rejected.

expired → const ApprovalStatus

Expired (timeout).

cancelled → const ApprovalStatus

Cancelled by requester.

escalated → const ApprovalStatus

Escalated to higher authority.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ApprovalStatus

Constants

values → const List<ApprovalStatus>
A constant List of the values in this enum, in order of their declaration.