AsrResult class

ASR transcription result.

Constructors

AsrResult({required String text, required double confidence, String? language, List<AsrSegment>? segments, required Duration audioDuration, required Duration processingTime})
const

Properties

audioDuration Duration
Audio duration.
final
confidence double
Confidence score (0.0 - 1.0).
final
hashCode int
The hash code for this object.
no setterinherited
language String?
Language detected or used.
final
processingTime Duration
Processing time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<AsrSegment>?
Transcript segments with timestamps.
final
text String
Full transcribed text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited