AssetContent class

Asset content.

Constructors

AssetContent({required String assetId, required String mimeType, required dynamic content, int? size, String? hash, Map<String, dynamic>? metadata})
const
AssetContent.fromJson(Map<String, dynamic> json)
factory

Properties

asBytes List<int>?
Get content as bytes.
no setter
assetId String
Asset identifier.
final
asString String?
Get content as string.
no setter
content → dynamic
Content (String or bytes).
final
hash String?
Content hash.
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
Additional metadata.
final
mimeType String
MIME type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited