AudienceConfig class

Configuration for audience adaptation.

Constructors

AudienceConfig({Expertise expertise = Expertise.intermediate, AudienceContext context = AudienceContext.internal, String? role, AudiencePreferences? preferences})
const
AudienceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

context AudienceContext
Communication context.
final
expertise Expertise
Audience expertise level.
final
hashCode int
The hash code for this object.
no setterinherited
preferences AudiencePreferences?
Audience preferences.
final
role String?
Specific role.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited