AudiencePreferences class
Audience preferences.
Constructors
- AudiencePreferences({String? preferredFormat, bool avoidJargon = false, bool includeDefinitions = false, VisualPreference visualPreference = VisualPreference.text})
-
const
-
AudiencePreferences.fromJson(Map<
String, dynamic> json) -
factory
Properties
- avoidJargon → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDefinitions → bool
-
final
- preferredFormat → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visualPreference → VisualPreference
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited