AuditFilter class

Audit query filter.

Constructors

AuditFilter({List<String>? types, String? actorId, String? workspaceId, DateTime? since, DateTime? until, int? limit})
const

Properties

actorId String?
Actor filter.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
since DateTime?
Earliest event time.
final
types List<String>?
Event type filter.
final
until DateTime?
Latest event time.
final
workspaceId String?
Workspace filter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited