Bundle class

A bundle containing packaged MCP resources.

Available extensions

Constructors

Bundle({required BundleManifest manifest, List<BundleResource> resources = const [], List<BundleDependency> dependencies = const [], Map<String, dynamic> metadata = const {}})
const
Bundle.fromJson(Map<String, dynamic> json)
Create a Bundle from JSON.
factory

Properties

dependencies List<BundleDependency>
Dependencies on other bundles.
final
factGraphs List<BundleResource>

Available on Bundle, provided by the BundleExtensions extension

Get all fact graph resources.
no setter
hashCode int
The hash code for this object.
no setterinherited
manifest → BundleManifest
Bundle manifest with metadata and configuration.
final
metadata Map<String, dynamic>
Additional metadata.
final
profiles List<BundleResource>

Available on Bundle, provided by the BundleExtensions extension

Get all profile resources.
no setter
resources List<BundleResource>
List of resources included in the bundle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skills List<BundleResource>

Available on Bundle, provided by the BundleExtensions extension

Get all skill resources.
no setter

Methods

copyWith({BundleManifest? manifest, List<BundleResource>? resources, List<BundleDependency>? dependencies, Map<String, dynamic>? metadata}) Bundle
Create a copy with modifications.
getResource(String path) BundleResource?

Available on Bundle, provided by the BundleExtensions extension

Get a resource by path.
getResourcesByType(ResourceType type) List<BundleResource>

Available on Bundle, provided by the BundleExtensions extension

Get resources by type.
hasCapability(String capability) bool

Available on Bundle, provided by the BundleExtensions extension

Check if bundle has a specific capability.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited