BundleDescriptor class

Bundle descriptor used by SkillRegistryPort.

Constructors

BundleDescriptor({required String id, required String name, required String version, List<String> skillIds = const [], Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Bundle identifier.
final
metadata Map<String, dynamic>
Additional metadata.
final
name String
Human-readable name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillIds List<String>
Skill identifiers exposed by the bundle.
final
version String
Version string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited