BundleManifest class

Bundle manifest containing metadata and configuration.

Constructors

BundleManifest({required String id, required String name, required String version, String? provider, String? description, String schemaVersion = currentSchemaVersion, BundleType type = BundleType.application, String? entryPoint, String? license, String? homepage, String? repository, List<String> capabilities = const [], List<String> tags = const [], List<BundleDependency> dependencies = const [], PlatformRequirements? platform, Map<String, dynamic> metadata = const {}})
const
BundleManifest.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

capabilities List<String>
Required capabilities.
final
dependencies List<BundleDependency>
Dependencies on other bundles.
final
description String?
Human-readable description.
final
entryPoint String?
Main entry point.
final
hashCode int
The hash code for this object.
no setterinherited
homepage String?
Homepage URL.
final
id String
Bundle identifier (unique).
final
license String?
License identifier (SPDX).
final
metadata Map<String, dynamic>
Additional metadata.
final
name String
Human-readable name.
final
platform PlatformRequirements?
Platform requirements.
final
provider String?
Provider/author identifier.
final
repository String?
Repository URL.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
Schema version this bundle conforms to.
final
tags List<String>
Tags for categorization.
final
type BundleType
Bundle type.
final
version String
Semantic version string.
final

Methods

copyWith({String? id, String? name, String? version, String? provider, String? description, String? schemaVersion, BundleType? type, String? entryPoint, String? license, String? homepage, String? repository, List<String>? capabilities, List<String>? tags, List<BundleDependency>? dependencies, PlatformRequirements? platform, Map<String, dynamic>? metadata}) BundleManifest
Create a copy with modifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited