BundleValidator class

Validates MCP bundles against schema and rules.

Constructors

BundleValidator({ValidatorOptions options = const ValidatorOptions()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
options ValidatorOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(Bundle bundle) ValidationResult
Validate a bundle.
validateProfile(ProfileManifest profile) ValidationResult
Validate a profile manifest.
validateSkill(SkillManifest skill) ValidationResult
Validate a skill manifest.

Operators

operator ==(Object other) bool
The equality operator.
inherited