CandidatesPort class abstract
Port for candidate fact operations.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
confirmCandidate(
String candidateId, {String? reviewerId}) → Future< void> - Confirm a candidate (promote to fact).
-
createCandidates(
List< CandidateRecord> candidates) → Future<List< String> > - Create a batch of candidates.
-
getPendingCandidates(
String workspaceId, {int? limit}) → Future< List< CandidateRecord> > - Get candidates in pending state for a workspace.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rejectCandidate(
String candidateId, String reason, {String? reviewerId}) → Future< void> - Reject a candidate with a reason.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited