CapabilityDescriptor class

Descriptor for a device capability (action it can perform).

Constructors

CapabilityDescriptor({required String action, SafetyClass safetyClass = SafetyClass.safe, Map<String, dynamic>? argsSchema, String? description})
const
CapabilityDescriptor.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

action String
Action name (e.g., 'moveTo', 'setSpeed').
final
argsSchema Map<String, dynamic>?
JSON schema describing the arguments.
final
description String?
Human-readable description of this capability.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyClass SafetyClass
Safety classification for this action.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited