ChannelDescriptor class

Descriptor for a channel within a device (e.g., axis, joint, sensor).

Constructors

ChannelDescriptor({required String id, required String name, required String type, List<ResourceDescriptor> resources = const [], List<ChannelDescriptor>? children})
const
ChannelDescriptor.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

children List<ChannelDescriptor>?
Optional nested child channels.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Channel identifier.
final
name String
Human-readable name.
final
resources List<ResourceDescriptor>
Resources available on this channel.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Channel type (ch, axis, joint, tag, reg, gpio, pwm, adc, dac).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited