ChunkMeta class

Chunk metadata for multi-part payloads.

Constructors

ChunkMeta({required int index, required int total, required String groupId})
const
ChunkMeta.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

groupId String
Group identifier linking related chunks.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Index of this chunk within the group.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of chunks in the group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited