ClaimsPort class abstract

Port for claim operations.

Implementers

Constructors

ClaimsPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClaim(String id) Future<Claim?>
Get a claim by ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryClaims(ClaimQuery query) Future<List<Claim>>
Query claims.
toString() String
A string representation of this object.
inherited
updateClaimStatus(String id, ClaimStatus status) Future<void>
Update the status of a claim.
validateClaims(List<Claim> claims, {DateTime? asOf, String? policyVersion}) Future<ClaimValidationReport>
Validate a set of claims against the fact graph.
writeClaims(List<Claim> claims, {List<String>? evidenceRefs}) Future<void>
Write claims with optional evidence links.

Operators

operator ==(Object other) bool
The equality operator.
inherited