ConditionalExpr class

Conditional/ternary expression (cond ? then : else).

Inheritance

Constructors

ConditionalExpr(Expr condition, Expr thenBranch, Expr elseBranch)
const

Properties

condition Expr
final
elseBranch Expr
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thenBranch Expr
final

Methods

accept<T>(ExprVisitor<T> visitor) → T
Accept a visitor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited