ConfidenceLevel enum
Semantic ranges for confidence interpretation.
Values
- veryLow → const ConfidenceLevel
-
const ConfidenceLevel(0.0, 0.3, 'Very Low') - low → const ConfidenceLevel
-
const ConfidenceLevel(0.3, 0.5, 'Low') - medium → const ConfidenceLevel
-
const ConfidenceLevel(0.5, 0.7, 'Medium') - high → const ConfidenceLevel
-
const ConfidenceLevel(0.7, 0.9, 'High') - veryHigh → const ConfidenceLevel
-
const ConfidenceLevel(0.9, 1.0, 'Very High')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- maxValue → double
-
final
- minValue → double
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromScore(
double score) → ConfidenceLevel - Get the confidence level for a given score.
Constants
-
values
→ const List<
ConfidenceLevel> - A constant List of the values in this enum, in order of their declaration.