ContextBundle class

Context bundle from FactGraph for skill execution.

Contains entities, events, views, and claims retrieved from the fact graph to provide context for skill execution.

Constructors

ContextBundle({required String id, List<ContextEntity> entities = const [], List<ContextEvent> events = const [], List<ContextView> views = const [], List<ContextClaim> claims = const [], required DateTime createdAt, int? estimatedTokens})
const
ContextBundle.empty()
Create an empty context bundle.
factory
ContextBundle.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

claims List<ContextClaim>
Claims from the context.
final
createdAt DateTime
When the bundle was created.
final
entities List<ContextEntity>
Retrieved entities.
final
estimatedTokens int?
Total token count estimate.
final
events List<ContextEvent>
Retrieved events.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Bundle ID.
final
isEmpty bool
Check if the bundle is empty.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
views List<ContextView>
Retrieved views/summaries.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override