ContextClaim class

Claim from context.

Constructors

ContextClaim({required String id, required String text, required double confidence, List<String> evidenceRefs = const []})
const
ContextClaim.fromJson(Map<String, dynamic> json)
factory

Properties

confidence double
Confidence score.
final
evidenceRefs List<String>
Evidence references.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Claim ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Claim text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override