ContextView class

View/summary from context.

Constructors

ContextView({required String id, required String type, required String content, required DateTime asOf})
const
ContextView.fromJson(Map<String, dynamic> json)
factory

Properties

asOf DateTime
Point-in-time snapshot.
final
content String
View content.
final
hashCode int
The hash code for this object.
no setteroverride
id String
View ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
View type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override