DateRange class

Helper class for resolved date ranges.

Constructors

DateRange({required DateTime start, required DateTime end})
const

Properties

duration Duration
Duration of the range.
no setter
end DateTime
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
final

Methods

contains(DateTime date) bool
Check if a date is within this range (inclusive).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override