DecisionGuidance class
Guidance returned when a policy condition matches.
Constructors
-
DecisionGuidance({required DecisionAction action, double? confidence, String? explanation, List<
DecisionModifier> modifiers = const [], Map<String, dynamic> ? metadata}) -
const
-
DecisionGuidance.fromJson(Map<
String, dynamic> json) -
factory
Properties
- action → DecisionAction
-
Recommended action.
final
- confidence → double?
-
Confidence in this recommendation (0.0 - 1.0).
final
- explanation → String?
-
Explanation for this guidance.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Custom metadata.
final
-
modifiers
→ List<
DecisionModifier> -
Additional modifiers for the decision.
final
- requiresApproval → bool
-
Check if this guidance requires approval.
no setter
- requiresEvidence → bool
-
Check if this guidance requires evidence.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getModifiers(
ModifierType type) → List< DecisionModifier> - Get all modifiers of a specific type.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultProceed → const DecisionGuidance
- Create default "proceed" guidance.
- proceed → const DecisionGuidance
- Alias for defaultProceed.