DeviceDescriptor class

Full descriptor for an IO device.

Constructors

DeviceDescriptor({required String deviceId, required String manufacturer, required String model, String? serial, String? version, required String transport, IoConnectionState connectionState = IoConnectionState.disconnected, List<CapabilityDescriptor> capabilities = const [], List<ChannelDescriptor> resourceTree = const []})
const
DeviceDescriptor.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

capabilities → List<CapabilityDescriptor>
List of capabilities this device supports.
final
connectionState → IoConnectionState
Current connection state.
final
deviceId → String
Unique device identifier.
final
hashCode → int
The hash code for this object.
no setterinherited
manufacturer → String
Device manufacturer.
final
model → String
Device model.
final
resourceTree → List<ChannelDescriptor>
Resource tree of channels and their resources.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serial → String?
Serial number.
final
transport → String
Transport protocol identifier.
final
version → String?
Firmware or software version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited