DeviceMatcher class

Rule for matching a device during auto-discovery.

Constructors

DeviceMatcher({required String type, required String pattern, Map<String, dynamic>? context})
DeviceMatcher.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

context Map<String, dynamic>?
Optional context for the match operation.
final
hashCode int
The hash code for this object.
no setterinherited
pattern String
Pattern to match against.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Matcher type (e.g., idn_query, serial_pattern, mac_address, ros_topic).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited