EntityRecord class

Canonical entity record.

Constructors

EntityRecord({required String id, required String workspaceId, required String type, required String name, Map<String, dynamic> properties = const {}, required DateTime createdAt, DateTime? updatedAt})
const

Properties

createdAt DateTime
Creation timestamp.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Entity identifier.
final
name String
Entity display name.
final
properties Map<String, dynamic>
Property bag.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Entity type.
final
updatedAt DateTime?
Last update timestamp.
final
workspaceId String
Workspace identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited