EthosScope class
Domain-specific applicability scope for an Ethos.
- Annotations
-
- @immutable
Constructors
-
EthosScope({required String domain, String? description, List<
String> ? tags}) -
const
-
EthosScope.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
Human-readable description.
final
- domain → String
-
Domain this scope applies to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Scope tags.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited