EthosStorePort class abstract

Port for ethos storage.

Implementers

Constructors

EthosStorePort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateEthos(String id) Future<void>
Activate the specified ethos as the current default.
getActiveEthosId() Future<String?>
Get the currently active ethos ID (null if none).
getEthos(String id) Future<EthosRecord?>
Get an ethos record by ID.
listEthos({int? limit}) Future<List<EthosRecord>>
List stored ethos records.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putEthos(EthosRecord ethos) Future<void>
Persist an ethos record.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited