EventPort class abstract

Event port for pub/sub.

Implementers

Constructors

EventPort()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(PortEvent event) → Future<void>
Publish an event.
subscribe(String eventType) → Stream<PortEvent>
Subscribe to events of a type.
subscribeAll() → Stream<PortEvent>
Subscribe to all events.
toString() → String
A string representation of this object.
inherited
unsubscribe(String eventType) → Future<void>
Unsubscribe from a type.

Operators

operator ==(Object other) → bool
The equality operator.
inherited