ExpressionStyle class

Complete expression style configuration.

Constructors

ExpressionStyle({required ToneConfig tone, required FormatConfig format, HedgingConfig? hedging, AudienceConfig? audience, LanguageConfig? language, Map<String, dynamic>? metadata})
const
ExpressionStyle.fromJson(Map<String, dynamic> json)
factory

Properties

audience AudienceConfig?
Audience configuration.
final
format FormatConfig
Format configuration.
final
hashCode int
The hash code for this object.
no setterinherited
hedging HedgingConfig?
Hedging configuration.
final
language LanguageConfig?
Language configuration.
final
metadata Map<String, dynamic>?
Custom metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tone ToneConfig
Tone configuration.
final

Methods

merge(ExpressionStyle? overrides) ExpressionStyle
Create a merged style with overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultStyle → const ExpressionStyle
Default neutral style.