FormAutoFixAction class
An auto-fix action applied during validation.
Constructors
-
FormAutoFixAction({required String action, required String path, required String description, Map<
String, dynamic> ? details}) -
FormAutoFixAction.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- action → String
-
Action type (e.g., 'set_default', 'trim', 'coerce').
final
- description → String
-
Description of the fix applied.
final
-
details
→ Map<
String, dynamic> ? -
Additional details about the fix.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
Path to the field that was fixed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited