FormBlockType enum

Type of content block within a form document.

Inheritance
Available extensions

Values

text → const FormBlockType

Plain text content.

heading → const FormBlockType

Heading content with level.

table → const FormBlockType

Tabular data.

chart → const FormBlockType

Chart visualization.

image → const FormBlockType

Image content.

formField → const FormBlockType

Interactive form field.

repeatable → const FormBlockType

Repeatable block template.

conditional → const FormBlockType

Conditional block with branching.

canvas → const FormBlockType

Live canvas scene embed — rendered against current project state via a CanvasBindingResolver. See FormCanvasBlock.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) FormBlockType
Parse a FormBlockType from its string name.

Constants

values → const List<FormBlockType>
A constant List of the values in this enum, in order of their declaration.