FormConditionalBlock class

A conditional block that renders different content based on a condition.

Inheritance

Constructors

FormConditionalBlock({required String blockId, required int index, Map<String, dynamic>? style, required String condition, required FormBlock thenBlock, FormBlock? elseBlock})
FormConditionalBlock.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

blockId String
Unique block identifier.
finalinherited
condition String
Condition expression to evaluate.
final
elseBlock FormBlock?
Optional block to render when the condition is false.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Block ordering index.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Map<String, dynamic>?
Optional style properties.
finalinherited
thenBlock FormBlock
Block to render when the condition is true.
final
type FormBlockType
Type of this block.
finalinherited

Methods

baseToJson() Map<String, dynamic>
Serialize common base fields to a map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited