FormDocument class

A form document instance created from a template.

Constructors

FormDocument({required String documentId, required String templateId, required String templateVersion, required FormDocumentMetadata metadata, FormDocumentStatus status = FormDocumentStatus.draft, int version = 1, List<FormSection> sections = const [], Map<String, dynamic> data = const {}, List<FormDataBinding>? bindings, List<FormValidationIssue>? validationIssues})
FormDocument.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

bindings List<FormDataBinding>?
Optional data bindings.
final
data Map<String, dynamic>
Document data values.
final
documentId String
Unique document identifier.
final
hashCode int
The hash code for this object.
no setterinherited
metadata FormDocumentMetadata
Document metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<FormSection>
Sections within the document.
final
status FormDocumentStatus
Current document status.
final
templateId String
Template this document was created from.
final
templateVersion String
Version of the template used.
final
validationIssues List<FormValidationIssue>?
Optional validation issues.
final
version int
Document version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited