FormDocumentMetadata class

Metadata associated with a form document.

Constructors

FormDocumentMetadata({required String author, required DateTime createdAt, DateTime? modifiedAt, DateTime? publishedAt, String? dataSource, String? engineVersion})
const
FormDocumentMetadata.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

author String
Author of the document.
final
createdAt DateTime
When the document was created.
final
dataSource String?
Data source identifier.
final
engineVersion String?
Engine version used to create the document.
final
hashCode int
The hash code for this object.
no setterinherited
modifiedAt DateTime?
When the document was last modified.
final
publishedAt DateTime?
When the document was published.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited