FormDocumentVersion class

A version entry in the document history.

Constructors

FormDocumentVersion({required int versionNumber, required DateTime timestamp, required String author, String? changeDescription, Map<String, dynamic>? diff})
FormDocumentVersion.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

author String
Author of this version.
final
changeDescription String?
Optional description of changes.
final
diff Map<String, dynamic>?
Optional diff from previous version.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When this version was created.
final
versionNumber int
Version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited