FormHeadingBlock class

A heading content block with level.

Inheritance

Constructors

FormHeadingBlock({required String blockId, required int index, Map<String, dynamic>? style, required String content, int level = 1, bool? numbering})
FormHeadingBlock.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

blockId String
Unique block identifier.
finalinherited
content String
Heading text.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Block ordering index.
finalinherited
level int
Heading level (1-6).
final
numbering bool?
Whether automatic numbering is applied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Map<String, dynamic>?
Optional style properties.
finalinherited
type FormBlockType
Type of this block.
finalinherited

Methods

baseToJson() Map<String, dynamic>
Serialize common base fields to a map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited