FormMargins class

Margin configuration for form layout.

Constructors

FormMargins({required double top, required double right, required double bottom, required double left})
const
FormMargins.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

bottom double
Bottom margin in millimeters.
final
hashCode int
The hash code for this object.
no setterinherited
left double
Left margin in millimeters.
final
Right margin in millimeters.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
Top margin in millimeters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited