FormPageSize class

Page size configuration for form layout.

Constructors

FormPageSize({required String size, required double width, required double height, String orientation = 'portrait'})
const
FormPageSize.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
Height in millimeters.
final
orientation String
Page orientation ('portrait' or 'landscape').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String
Named page size (e.g., 'A4', 'Letter').
final
width double
Width in millimeters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited