FormPatchOperation class

A JSON Patch operation for updating a form document.

Constructors

FormPatchOperation({required String op, required String path, dynamic value, String? from})
FormPatchOperation.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

from String?
Source path for move/copy operations.
final
hashCode int
The hash code for this object.
no setterinherited
op String
Operation type (e.g., 'add', 'remove', 'replace', 'move', 'copy', 'test').
final
path String
Target path in the document.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
Value for add/replace/test operations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited