FormRenderMetrics class

Rendering performance metrics.

Constructors

FormRenderMetrics({required double renderTimeMs, required int pageCount, int overflowCount = 0, int autofixCount = 0, int? fileSize})
const
FormRenderMetrics.fromJson(Map<String, dynamic> json)
factory

Properties

autofixCount int
Number of auto-fix actions applied.
final
fileSize int?
Output file size in bytes.
final
hashCode int
The hash code for this object.
no setterinherited
overflowCount int
Number of content overflow events.
final
pageCount int
Number of pages rendered.
final
renderTimeMs double
Time taken to render in milliseconds.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited