FormRendererPort class abstract

Pluggable renderer for multi-format output.

Implementations:

  • mcp_form: PdfRenderer, HtmlRenderer, DocxRenderer, MarkdownRenderer, AppPlayerUiRenderer
Implementers

Constructors

FormRendererPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMetadata() FormRendererMetadata
Get renderer metadata.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({required FormDocument document, required String format, Map<String, dynamic>? options}) Future<FormResult<FormRenderOutput>>
Render document to target format.
supportedFormats() List<String>
Get supported output formats.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited