FormTextBlock class

A plain text content block.

Inheritance

Constructors

FormTextBlock({required String blockId, required int index, Map<String, dynamic>? style, required String content, String format = 'plain'})
FormTextBlock.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

blockId String
Unique block identifier.
finalinherited
content String
Text content.
final
format String
Content format (e.g., 'plain', 'markdown', 'html').
final
hashCode int
The hash code for this object.
no setterinherited
index int
Block ordering index.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Map<String, dynamic>?
Optional style properties.
finalinherited
type FormBlockType
Type of this block.
finalinherited

Methods

baseToJson() Map<String, dynamic>
Serialize common base fields to a map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited