FormatConfig class

Configuration for response format.

Constructors

FormatConfig({required Structure structure, required Length length, bool includeEvidence = false, bool includeCaveats = false, bool includeAlternatives = false, bool includeNextSteps = false, int? maxParagraphs, int? maxBullets})
const
FormatConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
includeAlternatives bool
Whether to include alternatives.
final
includeCaveats bool
Whether to include caveats/disclaimers.
final
includeEvidence bool
Whether to include evidence/sources.
final
includeNextSteps bool
Whether to include next steps.
final
length Length
Response length.
final
maxBullets int?
Maximum bullets (for lists).
final
maxParagraphs int?
Maximum paragraphs (for prose).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structure Structure
Response structure.
final

Methods

merge(FormatConfig other) FormatConfig
Merge with another config.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultFormat → const FormatConfig
Default format.
standard → const FormatConfig
Standard default format.