FormattedResponse class

Formatted response from expression processing.

Constructors

FormattedResponse({required String content, required ExpressionStyle appliedStyle, List<String> hedgingApplied = const [], Map<String, dynamic>? metadata})
const
FormattedResponse.fromJson(Map<String, dynamic> json)
Create from JSON map.
factory

Properties

appliedStyle ExpressionStyle
Style that was applied.
final
content String
Formatted content.
final
hashCode int
The hash code for this object.
no setterinherited
hedgingApplied List<String>
Hedging phrases that were applied.
final
metadata Map<String, dynamic>?
Additional metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited