InMemoryBinaryStoragePort class

In-memory binary storage for testing.

Implemented types

Constructors

InMemoryBinaryStoragePort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String reference) Future<bool>
Delete a stored asset.
override
exists(String reference) Future<bool>
Check if a reference exists.
override
list([String? prefix]) Future<List<String>>
List all stored references with optional prefix.
override
metadata(String reference) Future<StorageMetadata?>
Get metadata for a reference.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieve(String reference) Future<Uint8List>
Retrieve binary data by reference.
override
store(Stream<List<int>> data, String mimeType, [StorageOptions options = const StorageOptions()]) Future<String>
Store binary data and return a reference.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited