InterventionResult class

Result of a pipeline intervention.

Annotations
  • @immutable

Constructors

InterventionResult({required InterventionPoint point, List<AppliedIntervention> interventions = const [], bool prohibitionViolated = false, List<String> prohibitionViolationIds = const [], bool modified = false, Map<String, dynamic>? modifications, DateTime? appliedAt})
InterventionResult.fromJson(Map<String, dynamic> json)
factory
InterventionResult.noOp()
Factory for no-operation result.
factory

Properties

appliedAt DateTime
Timestamp of intervention.
final
blocksDelivery bool
Whether this result blocks the pipeline.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasInterventions bool
Whether any intervention was applied.
no setter
interventions List<AppliedIntervention>
List of applied interventions.
final
modifications Map<String, dynamic>?
Description of what changed.
final
modified bool
Whether pipeline data was modified.
final
point InterventionPoint
Which pipeline stage was intervened.
final
prohibitionViolated bool
Whether a hard prohibition was violated.
final
prohibitionViolationIds List<String>
IDs of violated prohibitions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited