IoAuditPort class abstract

Port for recording and querying IO device audit trails.

Implementers

Constructors

IoAuditPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

export(IoAuditExportConfig config) Future<void>
Export audit records to an external system.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(IoAuditQuery query) Future<List<IoAuditRecord>>
Query audit records with filters.
record(IoAuditRecord record) Future<void>
Record an audit entry. Fire-and-forget (non-blocking).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited