IoAuditQuery class

Filter criteria for querying audit records.

Constructors

IoAuditQuery({String? deviceId, String? actorId, IoAuditType? type, DateTime? from, DateTime? to, int? limit, int? offset})
const
IoAuditQuery.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

actorId String?
Filter by actor identifier.
final
deviceId String?
Filter by device identifier.
final
from DateTime?
Start of time range (inclusive).
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum number of records to return.
final
offset int?
Number of records to skip for pagination.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to DateTime?
End of time range (inclusive).
final
type IoAuditType?
Filter by audit type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited