IoAuditType enum

Type of auditable IO operation.

Inheritance
Available extensions

Values

execute → const IoAuditType
emergencyStop → const IoAuditType
readAccess → const IoAuditType
subscribeAccess → const IoAuditType
policyChange → const IoAuditType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) IoAuditType
Parse from string, defaulting to execute.

Constants

values → const List<IoAuditType>
A constant List of the values in this enum, in order of their declaration.