IoError class

Error information from an IO operation.

Constructors

IoError({required String code, required String message, required DateTime timestamp, Map<String, dynamic>? details})
const
IoError.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

code String
Error code.
final
details Map<String, dynamic>?
Additional error details.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When the error occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited