IoStreamSubscription class

Active subscription with its associated data stream.

Named IoStreamSubscription to avoid collision with dart:async StreamSubscription.

Constructors

IoStreamSubscription({required SubscriptionHandle handle, required Stream<PayloadEnvelope> stream})

Properties

handle SubscriptionHandle
Handle identifying this subscription.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<PayloadEnvelope>
Stream of payload envelopes from the subscribed topic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited