KnowledgeSection class

Knowledge section containing knowledge sources.

Constructors

KnowledgeSection({String schemaVersion = '1.0.0', List<KnowledgeSource> sources = const [], RetrieverConfig? retriever, IndexConfig? index})
const
KnowledgeSection.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
index IndexConfig?
Index configuration.
final
retriever RetrieverConfig?
Retriever configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
Schema version for knowledge section.
final
sources List<KnowledgeSource>
Knowledge sources.
final

Methods

getSource(String sourceId) KnowledgeSource?
Get source by ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited