KvStoragePort class abstract

Key-value storage port.

Implementers

Constructors

KvStoragePort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all data.
exists(String key) Future<bool>
Check if key exists.
get(String key) Future
Get a value.
keys({String? prefix}) Future<List<String>>
List keys with optional prefix.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<void>
Remove a value.
set(String key, dynamic value) Future<void>
Set a value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited