LanguageConfig class

Configuration for language and localization.

Constructors

LanguageConfig({String? locale, VocabularyConfig? vocabulary, GrammarConfig? grammar})
const
LanguageConfig.fromJson(Map<String, dynamic> json)
factory

Properties

grammar GrammarConfig?
Grammar configuration.
final
hashCode int
The hash code for this object.
no setterinherited
locale String?
Locale (e.g., "en-US", "ko-KR").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vocabulary VocabularyConfig?
Vocabulary configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited