LlmToolCall class

Tool call from LLM.

Constructors

LlmToolCall({required String id, required String name, required Map<String, dynamic> arguments})
const
LlmToolCall.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

arguments Map<String, dynamic>
Parsed arguments.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique call ID.
final
name String
Tool name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited