MatchedCriterion class

Matched judgment criterion result.

Annotations
  • @immutable

Constructors

MatchedCriterion({required String criterionId, required String preferredAction, required double matchStrength, bool hasConflict = false, String? conflictWith, String? conflictAnnotation})
const
MatchedCriterion.fromJson(Map<String, dynamic> json)
factory

Properties

conflictAnnotation String?
Description of the conflict.
final
conflictWith String?
ID of conflicting criterion.
final
criterionId String
ID of the matched criterion.
final
hasConflict bool
Whether this conflicts with another matched criterion.
final
hashCode int
The hash code for this object.
no setterinherited
matchStrength double
How strongly conditions matched (0.0-1.0).
final
preferredAction String
Preferred action from the criterion.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited