MetricEvent class

Metric event for streaming.

Constructors

MetricEvent({required String name, required MetricValue value, required String eventType})
const
MetricEvent.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

eventType String
Event type (update, threshold, anomaly).
final
hashCode int
The hash code for this object.
no setterinherited
name String
Metric name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value MetricValue
Metric value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited