MetricResult class

Result for a single computed metric.

Constructors

MetricResult({required String id, double? rawValue, required double normalizedValue, required MetricSourceType sourceType, required double confidence})
const
MetricResult.fromJson(Map<String, dynamic> json)
factory

Properties

confidence double
Confidence in the computed value (0.0 - 1.0).
final
hashCode int
The hash code for this object.
no setterinherited
id String
Metric ID.
final
isHighConfidence bool
Check if this is a high confidence result.
no setter
isLowConfidence bool
Check if this is a low confidence result.
no setter
isMediumConfidence bool
Check if this is a medium confidence result.
no setter
normalizedValue double
Normalized value (0.0 - 1.0).
final
rawValue double?
Raw computed value (null if computation failed).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType MetricSourceType
Source type used for computation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited