MetricSourceType enum

Source type for metric computation.

Inheritance
Available extensions

Values

factgraph → const MetricSourceType

From fact graph queries.

computed → const MetricSourceType

Computed from other metrics.

static_ → const MetricSourceType

Fixed static value.

llmDerived → const MetricSourceType

LLM-derived analysis.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
JSON serialization name (snake_case per spec).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String value) MetricSourceType
Parse from JSON string.

Constants

values → const List<MetricSourceType>
A constant List of the values in this enum, in order of their declaration.