MetricSpec class

Specification for on-demand metric computation.

Constructors

MetricSpec({required String id, required String entityId, Period? period, Map<String, dynamic>? parameters})
const

Properties

entityId String
Entity identifier (target).
final
hashCode int
The hash code for this object.
no setterinherited
id String
Metric identifier.
final
parameters Map<String, dynamic>?
Computation parameters.
final
period Period?
Period.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited