ModifierType enum

Types of decision modifiers.

Inheritance
Available extensions

Values

requireEvidence → const ModifierType

Need more evidence before proceeding.

requireApproval → const ModifierType

Need human approval before proceeding.

addDisclaimer → const ModifierType

Include warning/disclaimer in output.

limitScope → const ModifierType

Reduce scope of action.

reduceConfidence → const ModifierType

Lower confidence in output.

increaseValidation → const ModifierType

Add extra validation steps.

notify → const ModifierType

Send notification.

log → const ModifierType

Enhanced logging.

custom → const ModifierType

Application-specific modifier.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonName() String

Available on ModifierType, provided by the ModifierTypeExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ModifierType>
A constant List of the values in this enum, in order of their declaration.