MultiLayerContext class

Multi-layer context for tension detection.

Annotations
  • @immutable

Constructors

MultiLayerContext({required PhilosophyEvaluationContext philosophyContext, Map<String, dynamic>? profileState, Map<String, dynamic>? stateWeighting, Map<String, dynamic>? knowledgeProvenance, DateTime? assembledAt})
MultiLayerContext.fromJson(Map<String, dynamic> json)
factory

Properties

assembledAt DateTime
Assembly timestamp.
final
hashCode int
The hash code for this object.
no setterinherited
hasKnowledgeProvenance bool
Whether knowledge provenance is available.
no setter
hasProfileState bool
Whether profile state is available for tension detection.
no setter
knowledgeProvenance Map<String, dynamic>?
Knowledge provenance.
final
philosophyContext PhilosophyEvaluationContext
Philosophy layer state.
final
profileState Map<String, dynamic>?
Profile layer state.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateWeighting Map<String, dynamic>?
State/weighting layer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited