NotificationRecord class

Historical notification record.

Constructors

NotificationRecord({required Notification notification, required NotificationResult result, required DateTime createdAt, required DateTime updatedAt})
const
NotificationRecord.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
When the notification was created.
final
hashCode int
The hash code for this object.
no setterinherited
notification Notification
Original notification.
final
result NotificationResult
Delivery result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
When it was last updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited