NotificationStatus enum

Status of a notification.

Inheritance
Available extensions

Values

queued → const NotificationStatus

Notification is queued for delivery.

sending → const NotificationStatus

Notification is being sent.

delivered → const NotificationStatus

Notification was delivered.

failed → const NotificationStatus

Delivery failed.

cancelled → const NotificationStatus

Notification was cancelled.

expired → const NotificationStatus

Notification expired before delivery.

read → const NotificationStatus

Notification was read/acknowledged.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) NotificationStatus

Constants

values → const List<NotificationStatus>
A constant List of the values in this enum, in order of their declaration.