OcrRegion class

OCR region with position.

Constructors

OcrRegion({required String text, required double confidence, required BoundingBox boundingBox})
const

Properties

boundingBox BoundingBox
Bounding box.
final
confidence double
Confidence score.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Region text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited