PassagePosition class

Position of passage in source document.

Constructors

PassagePosition({int? startOffset, int? endOffset, int? page, String? section})
const
PassagePosition.fromJson(Map<String, dynamic> json)
factory

Properties

endOffset int?
End character offset.
final
hashCode int
The hash code for this object.
no setterinherited
page int?
Page number (for PDFs).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
section String?
Section identifier.
final
startOffset int?
Start character offset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited