PatternQuery class

Query descriptor for PatternsPort.queryPatterns.

Constructors

PatternQuery({required String workspaceId, String? type, String? entityId, int? minFrequency, int? limit})
const

Properties

entityId String?
Entity filter.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum results.
final
minFrequency int?
Minimum frequency filter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Pattern type filter.
final
workspaceId String
Workspace identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited