PatternsPort class abstract

Port for pattern operations.

Implementers

Constructors

PatternsPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPattern(String id) Future<PatternRecord?>
Get a pattern by ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryPatterns(PatternQuery query) Future<List<PatternRecord>>
Query patterns by workspace/type/entity/frequency.
storePattern(PatternRecord pattern) Future<String>
Store a pattern.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited