hasProfileState property
bool
get
hasProfileState
Whether this context has profile state for tension detection.
Implementation
bool get hasProfileState => profileState != null;
Whether this context has profile state for tension detection.
bool get hasProfileState => profileState != null;