PipelineRunHandle class

Pipeline run handle.

Constructors

PipelineRunHandle({required String runId, required String pipelineId, required String status, required DateTime startedAt, DateTime? finishedAt, Map<String, dynamic>? output, String? error})
const

Properties

error String?
Error message if failed.
final
finishedAt DateTime?
Completion timestamp.
final
hashCode int
The hash code for this object.
no setterinherited
output Map<String, dynamic>?
Output payload.
final
pipelineId String
Pipeline identifier.
final
runId String
Run identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
Start timestamp.
final
status String
Run status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited