PlatformRequirements class
Platform requirements for the bundle.
Constructors
-
PlatformRequirements({String? dartSdk, String? flutterSdk, List<
String> os = const [], List<String> envVars = const []}) -
const
-
PlatformRequirements.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dartSdk → String?
-
Minimum Dart SDK version.
final
-
envVars
→ List<
String> -
Required environment variables.
final
- flutterSdk → String?
-
Minimum Flutter SDK version.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
os
→ List<
String> -
Supported operating systems.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited