PolicyConstraints class

Constraints applied when a policy rule allows an action.

Constructors

PolicyConstraints({Map<String, Bound>? bounds, RateLimit? rateLimit, List<Interlock>? interlocks, bool? requireApproval})
const
PolicyConstraints.fromJson(Map<String, dynamic> json)
factory

Properties

bounds Map<String, Bound>?
Numeric bounds per argument name.
final
hashCode int
The hash code for this object.
no setterinherited
interlocks List<Interlock>?
Interlocks that must pass before the action proceeds.
final
rateLimit RateLimit?
Rate limit for the action.
final
requireApproval bool?
Whether explicit approval is required even when allowed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited