PolicyDecision class

Result of evaluating a policy against an action.

Constructors

PolicyDecision({required Decision decision, String? ruleId, String? notes})
const
PolicyDecision.fromJson(Map<String, dynamic> json)
factory

Properties

decision Decision
The decision outcome.
final
hashCode int
The hash code for this object.
no setterinherited
notes String?
Optional human-readable notes explaining the decision.
final
ruleId String?
ID of the rule that produced this decision, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited