Prohibition class

Absolute boundary with severity classification.

Annotations
  • @immutable

Constructors

Prohibition({required String id, required String statement, required ProhibitionSeverity severity, required String rationale, List<ProhibitionException>? exceptions, List<String> forbiddenPatterns = const []})
const
Prohibition.fromJson(Map<String, dynamic> json)
factory

Properties

exceptions → List<ProhibitionException>?
Explicit exceptions to this prohibition.
final
forbiddenPatterns → List<String>
Literal patterns whose case-insensitive presence in a proposed output/action deterministically marks this prohibition violated.
final
hasExceptions → bool
Whether this prohibition has explicit exceptions.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier.
final
isHard → bool
Whether this is a hard (blocking) prohibition.
no setter
rationale → String
Why this boundary exists.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → ProhibitionSeverity
hard = blocking, soft = warning.
final
statement → String
The boundary statement.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited