ProhibitionCheckResult class

Result of prohibition checks.

Annotations
  • @immutable

Constructors

ProhibitionCheckResult({required List<ProhibitionCheck> checks, required bool hasHardViolation, List<String> hardViolationIds = const [], List<String> softViolationIds = const []})
const
ProhibitionCheckResult.allPassed(List<ProhibitionCheck> checks)
Factory for all-pass result.
factory
ProhibitionCheckResult.fromJson(Map<String, dynamic> json)
factory

Properties

checks List<ProhibitionCheck>
Individual check results.
final
hardViolationIds List<String>
IDs of violated hard prohibitions.
final
hasHardViolation bool
Whether any hard prohibition was violated.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softViolationIds List<String>
IDs of violated soft prohibitions.
final
violations List<ProhibitionCheck>
Get only violated checks.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited