ProhibitionException class

Exception condition for a prohibition.

Annotations
  • @immutable

Constructors

ProhibitionException({required String condition, required String justificationRequired})
const
ProhibitionException.fromJson(Map<String, dynamic> json)
factory

Properties

condition String
When the exception applies.
final
hashCode int
The hash code for this object.
no setterinherited
justificationRequired String
Required justification for applying exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited