ProposedChange class
Specific change details for an evolution proposal.
- Annotations
-
- @immutable
Constructors
-
ProposedChange({Map<
String, dynamic> ? before, Map<String, dynamic> ? after, String? diff}) -
const
-
ProposedChange.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
after
→ Map<
String, dynamic> ? -
Proposed state.
final
-
before
→ Map<
String, dynamic> ? -
Current state (for audit).
final
- diff → String?
-
Human-readable diff description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited