RateLimit class

Rate limit constraint for action invocations.

Constructors

RateLimit({required int maxCalls, required Duration window})
RateLimit.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxCalls int
Maximum number of calls allowed within window.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
window Duration
Time window over which maxCalls is measured.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited