ReadResult class
Result of a read operation.
Constructors
-
ReadResult({List<
ReadResultItem> items = const [], ReadTiming? timing}) -
const
-
ReadResult.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
ReadResultItem> -
Individual read result items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timing → ReadTiming?
-
Timing information.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited