ReadSpec class
Specification for a read operation.
Constructors
-
ReadSpec({required List<
String> targets, ReadOptions? options}) -
const
-
ReadSpec.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → ReadOptions?
-
Read options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targets
→ List<
String> -
Target resource URIs to read.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited