RegistryEventType enum
Type of registry lifecycle event.
Values
- deviceRegistered → const RegistryEventType
-
A device was registered in the registry.
- deviceUnregistered → const RegistryEventType
-
A device was unregistered from the registry.
- deviceConnected → const RegistryEventType
-
A device established a connection.
- deviceDisconnected → const RegistryEventType
-
A device lost its connection.
- deviceError → const RegistryEventType
-
A device encountered an error.
- adapterRegistered → const RegistryEventType
-
An adapter was registered in the registry.
- adapterUnregistered → const RegistryEventType
-
An adapter was unregistered from the registry.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → RegistryEventType - Parse a RegistryEventType from its string name.
Constants
-
values
→ const List<
RegistryEventType> - A constant List of the values in this enum, in order of their declaration.