ResourceInfo class

Resource information.

Constructors

ResourceInfo({required String uri, required String name, String? description, String? mimeType, String? serverId})
const

Properties

description String?
Description.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
MIME type.
final
name String
Resource name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverId String?
Optional server identifier that advertises this resource.
final
uri String
Resource URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited