RunbookDescriptor class

Runbook descriptor.

Constructors

RunbookDescriptor({required String id, required String name, String? description, List<String> tags = const []})
const

Properties

description String?
Description.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Runbook identifier.
final
name String
Runbook name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
Tags for discovery.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited