ScheduleTriggerPort class abstract

Port for scheduled and event-based triggers.

Implementers

Constructors

ScheduleTriggerPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schedule(String cron, ScheduleTarget target) Future<String>
Schedule a target by cron expression. Returns a schedule ID.
toString() String
A string representation of this object.
inherited
trigger(ScheduleTarget target, Map<String, dynamic> event) Future<void>
Fire a trigger on the given target.
unschedule(String scheduleId) Future<void>
Unschedule by schedule ID.

Operators

operator ==(Object other) bool
The equality operator.
inherited