SkillRuntimePort class abstract

Port for skill execution.

Implementers

Constructors

SkillRuntimePort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(String runId) Future<void>
Cancel a running skill.
executeSkill(String skillId, Map<String, dynamic> inputs, {Map<String, dynamic>? context}) Future<SkillRunHandle>
Execute a skill.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited