StateDefinition class

State definition.

Constructors

StateDefinition({dynamic initialValue, String type = 'dynamic', bool persist = false, String? computed})
const
StateDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

computed String?
Computed expression.
final
hashCode int
The hash code for this object.
no setterinherited
initialValue → dynamic
Initial value.
final
persist bool
Whether persisted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
State type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited