StorageOptions class

Storage options.

Constructors

StorageOptions({bool contentAddressable = true, String? prefix, int ttlSeconds = 0})
const

Properties

contentAddressable bool
Content-addressable storage (use hash as key).
final
hashCode int
The hash code for this object.
no setterinherited
prefix String?
Custom prefix for keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlSeconds int
TTL in seconds (0 = no expiry).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited