StubAnalysisDataSourcePort class
Stub data source port for testing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSourceMetadata(
{required AnalysisSourceType sourceType, required String query}) → Future< AnalysisSourceSchema> -
Retrieve source metadata (schema, columns, types, units).
override
-
isAvailable(
AnalysisSourceType sourceType) → Future< bool> -
Check if source is accessible.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryData(
{required AnalysisSourceType sourceType, required String query, Map< String, dynamic> ? filter, AnalysisTimeRange? timeRange}) → Future<AnalysisDataSet> -
Fetch data from source based on spec.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited