StubCandidatesPort class

Stub implementation for testing.

Implemented types

Constructors

StubCandidatesPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmCandidate(String candidateId, {String? reviewerId}) Future<void>
Confirm a candidate (promote to fact).
override
createCandidates(List<CandidateRecord> candidates) Future<List<String>>
Create a batch of candidates.
override
getPendingCandidates(String workspaceId, {int? limit}) Future<List<CandidateRecord>>
Get candidates in pending state for a workspace.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectCandidate(String candidateId, String reason, {String? reviewerId}) Future<void>
Reject a candidate with a reason.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited