StubDecisionPort class
Stub decision port for testing.
- Implemented types
Constructors
- StubDecisionPort()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decide(
String policy, Map< String, dynamic> context) → Future<DecisionGuidance> -
Evaluate the decision policy.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited