StubEntitiesPort class

Stub implementation for testing.

Implemented types

Constructors

StubEntitiesPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEntity(String entityId) Future<EntityRecord?>
Get an entity by ID.
override
linkEntity(String sourceId, String targetId, String relation, {Map<String, dynamic>? attributes}) Future<void>
Link an entity to another by a typed relationship.
override
mergeEntities(String surviving, String absorbed) Future<EntityRecord>
Merge two entities; surviving absorbs absorbed.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryEntities(EntityQuery query) Future<List<EntityRecord>>
Query entities.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited