StubEvidencePort class

Stub evidence port for testing.

Implemented types

Constructors

StubEvidencePort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

classifyFragment(String fragment) Future<String>
Classify fragment type.
override
computeConfidence(String fragment) Future<double>
Compute confidence score for a fragment.
override
extractFragments(String content, String mimeType) Future<List<EvidenceFragment>>
Extract fragments from content.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited