StubExpressionPort class

Stub expression port for testing.

Implemented types

Constructors

StubExpressionPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractVariables(String template) List<String>
Extract variable names from template.
override
format(String template, Map<String, dynamic> variables) String
Format a template with variables.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(ExpressionStyle style, Map<String, dynamic> data) String
Render a style onto data (optional capability — default throws).
override
toString() String
A string representation of this object.
inherited
validate(String template) bool
Validate a template.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited