StubFactsPort class

Stub implementation for testing.

Implemented types

Constructors

StubFactsPort()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteFacts(List<String> ids) → Future<void>
Delete facts by ID.
override
getFact(String id) → Future<FactRecord?>
Get a single fact by ID.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryFacts(FactQuery query) → Future<List<FactRecord>>
Query facts by workspace, type, period, entity, or custom filters.
override
toString() → String
A string representation of this object.
inherited
writeFacts(List<FactRecord> facts) → Future<void>
Write a batch of facts.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited