StubIndexPort class

Stub implementation for testing.

Implemented types

Constructors

StubIndexPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildIndex(String id, IndexBuildConfig config) Future<void>
Build a knowledge index.
override
dropIndex(String id) Future<void>
Drop an index.
override
indexExists(String id) Future<bool>
Check whether an index exists.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited