StubPatternsPort class

Stub implementation for testing.

Implemented types

Constructors

StubPatternsPort()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPattern(String id) → Future<PatternRecord?>
Get a pattern by ID.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryPatterns(PatternQuery query) → Future<List<PatternRecord>>
Query patterns by workspace/type/entity/frequency.
override
storePattern(PatternRecord pattern) → Future<String>
Store a pattern.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited