StubSkillRegistryPort class

Stub implementation for testing.

Implemented types

Constructors

StubSkillRegistryPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBundle(String id) Future<BundleDescriptor?>
Get a bundle descriptor by ID.
override
listBundles() Future<List<BundleDescriptor>>
List all registered bundles.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerBundle(BundleDescriptor descriptor) Future<void>
Register a bundle by manifest payload.
override
toString() String
A string representation of this object.
inherited
unregister(String id) Future<void>
Unregister a bundle.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited