StubSummariesPort class

Stub implementation for testing.

Implemented types

Constructors

StubSummariesPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStaleSummaries({int? limit}) Future<List<SummaryRecord>>
Get stale summaries scheduled for refresh.
override
getSummary(String entityId, String summaryType, {Period? period}) Future<SummaryRecord?>
Get a summary by entity and type.
override
markSummariesStale(List<String> entityIds, {String? summaryType}) Future<void>
Mark summaries as stale (to be refreshed by workers).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshSummary(String entityId, String summaryType, {Period? period}) Future<SummaryRecord>
Recompute a summary on demand.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited