StubWorkflowPort class

Stub implementation for testing.

Implemented types

Constructors

StubWorkflowPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRun(String runId) Future<WorkflowRunHandle?>
Get a workflow run by ID.
override
listWorkflows() Future<List<WorkflowDescriptor>>
List registered workflows.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runWorkflow(String id, Map<String, dynamic> input) Future<WorkflowRunHandle>
Run a workflow.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited