SummaryRecord class

Canonical summary record.

Constructors

SummaryRecord({required String id, required String entityId, required String type, required String content, double confidence = 1.0, bool isStale = false, Period? period, List<String> sourceFactIds = const [], required DateTime createdAt, DateTime? refreshedAt})
const

Properties

confidence double
Confidence score.
final
content String
Summary content.
final
createdAt DateTime
Creation timestamp.
final
entityId String
Entity identifier.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Summary identifier.
final
isStale bool
Whether the summary is stale and needs refresh.
final
period Period?
Period covered.
final
refreshedAt DateTime?
Last refresh timestamp.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceFactIds List<String>
Source fact identifiers.
final
type String
Summary type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited