TensionResolution class

Resolution of a detected tension.

Annotations
  • @immutable

Constructors

TensionResolution({required String tensionId, required ResolutionStrategy strategy, required String outcome, required double confidence, Map<String, dynamic>? adjustments, DateTime? resolvedAt})
TensionResolution.fromJson(Map<String, dynamic> json)
factory

Properties

adjustments Map<String, dynamic>?
Changes applied.
final
confidence double
Confidence in the resolution (0.0-1.0).
final
hashCode int
The hash code for this object.
no setterinherited
outcome String
Description of resolution outcome.
final
resolvedAt DateTime
When the tension was resolved.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strategy ResolutionStrategy
Strategy used for resolution.
final
tensionId String
ID of the resolved tension.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited