TensionSource class

Source of a tension (which layers are in conflict).

Annotations
  • @immutable

Constructors

TensionSource({TensionLayer primaryLayer = TensionLayer.philosophy, required TensionLayer opposingLayer, String? primaryComponentId, String? opposingComponentId})
const
TensionSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
opposingComponentId String?
Specific opposing component ID.
final
opposingLayer TensionLayer
The opposing layer: profile, knowledge, or state.
final
primaryComponentId String?
Specific ethos component ID.
final
primaryLayer TensionLayer
Always philosophy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited