ToneConfig class

Configuration for communication tone.

Constructors

ToneConfig({required Formality formality, required ToneConfidence confidence, required Empathy empathy, required Directness directness})
const
ToneConfig.fromJson(Map<String, dynamic> json)
factory

Properties

confidence ToneConfidence
Certainty expression.
final
directness Directness
Communication style.
final
empathy Empathy
Emotional acknowledgment.
final
formality Formality
Language register.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(ToneConfig other) ToneConfig
Merge with another config.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

neutral → const ToneConfig
Neutral default tone.