TopicOptions class

Options for a topic subscription.

Constructors

TopicOptions({int? intervalMs, int? bufferSize, BackpressurePolicy? backpressure, int? ttlSeconds})
const
TopicOptions.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

backpressure BackpressurePolicy?
Backpressure handling policy.
final
bufferSize int?
Maximum buffer size.
final
hashCode int
The hash code for this object.
no setterinherited
intervalMs int?
Polling interval in milliseconds (for poll mode).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlSeconds int?
Time-to-live in seconds for buffered messages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited