TopicSpec class

Specification for a topic subscription.

Constructors

TopicSpec({required String uri, required TopicMode mode, TopicOptions? options})
const
TopicSpec.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode TopicMode
Delivery mode for the subscription.
final
options TopicOptions?
Subscription options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
Resource URI to subscribe to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited