TransportType enum

Transport protocol type for device communication.

Inheritance
Available extensions

Values

tcp → const TransportType
serial → const TransportType
usb → const TransportType
ble → const TransportType
can → const TransportType
mqtt → const TransportType
ros2 → const TransportType
custom → const TransportType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) TransportType

Constants

values → const List<TransportType>
A constant List of the values in this enum, in order of their declaration.