UiError class

Structured error for UiPort operations.

Constructors

UiError({required String code, required String message, String? path, Map<String, dynamic>? context})
UiError.fromJson(Map<String, dynamic> json)
factory

Properties

code String
Machine-readable error code.
final
context Map<String, dynamic>?
Additional context for the error.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
path String?
JSON path where the error occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited