ValidationIssue class abstract

Base class for validation issues.

Implementers

Constructors

ValidationIssue()

Properties

code String
Issue code.
no setter
hashCode int
The hash code for this object.
no setterinherited
location String?
Location in the bundle where the issue was found.
no setter
message String
Human-readable message.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity ValidationSeverity
Severity level.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited