VisionFace class

Vision face detection.

Constructors

VisionFace({required BoundingBox boundingBox, required double confidence, Map<String, double>? emotions})
const

Properties

boundingBox → BoundingBox
final
confidence → double
final
emotions → Map<String, double>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited