VisionOptions class

Vision processing options.

Constructors

VisionOptions({bool detailed = true, bool detectObjects = false, bool detectFaces = false, bool extractText = false, String? prompt})
const

Properties

detailed bool
Whether to generate detailed description.
final
detectFaces bool
Whether to detect faces.
final
detectObjects bool
Whether to detect objects.
final
extractText bool
Whether to extract text (separate from OCR).
final
hashCode int
The hash code for this object.
no setterinherited
prompt String?
Custom prompt for analysis.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited