VisionPort class abstract interface

Port for vision analysis operations.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe(Stream<List<int>> imageData, VisionOptions options) Future<VisionResult>
Analyze and describe an image.
isAvailable() Future<bool>
Check if the vision engine is available.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited