VisionResult class

Vision analysis result.

Constructors

VisionResult({required String description, List<VisionLabel>? labels, String? text, List<VisionFace>? faces, required double confidence, required Duration processingTime})
const

Properties

confidence double
Confidence score (0.0 - 1.0).
final
description String
Text description of the image.
final
faces List<VisionFace>?
Detected faces.
final
hashCode int
The hash code for this object.
no setterinherited
labels List<VisionLabel>?
Detected objects/labels.
final
processingTime Duration
Processing time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Detected text (OCR).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited