AssetNotFoundException class

Exception when asset is not found.

Implemented types

Constructors

AssetNotFoundException(String assetId)

Properties

assetId String
Asset ID that was not found.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited