CelmAttempt class

One thing the runtime tried, and what came of it.

Constructors

CelmAttempt({required String step, required String action, required String result, required DateTime at, String? why})
const
CelmAttempt.fromJson(Map<String, dynamic> json)
factory

Properties

action String
final
at DateTime
final
hashCode int
The hash code for this object.
no setterinherited
result String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step String
final
why String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited