CelmCancelled class
Stopped by a caller. What was observed before the stop was still observed, so the evidence stands.
- Inheritance
-
- Object
- CelmOutcome
- CelmCancelled
Constructors
-
CelmCancelled(String runId, {required String stoppedAt, List<
CelmConclusion> conclusions = const []}) -
const
Properties
-
conclusions
→ List<
CelmConclusion> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stoppedAt → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited