CelmCompleted class
The goal's completion held.
- Inheritance
-
- Object
- CelmOutcome
- CelmCompleted
Constructors
-
CelmCompleted(String runId, {List<
CelmConclusion> conclusions = const [], required CelmBudgetUse budget}) -
const
Properties
- budget → CelmBudgetUse
-
final
-
conclusions
→ List<
CelmConclusion> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited