outcome property
Set once the run has ended. Null while it is running or suspended. This is how a caller that only has the id reads the result.
Implementation
final CelmOutcome? outcome;
Set once the run has ended. Null while it is running or suspended. This is how a caller that only has the id reads the result.
final CelmOutcome? outcome;