CelmRefused class

The run could not be started or could not be permitted.

Inheritance

Constructors

CelmRefused(String runId, {required CelmRefusalReason reason, String detail = ''})
const

Properties

detail String
final
hashCode int
The hash code for this object.
no setterinherited
reason CelmRefusalReason
final
runId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited