ChannelAttachment class

Attachment in a channel event.

Constructors

ChannelAttachment({required String type, required String url, String? filename, String? mimeType, int? size})
const
ChannelAttachment.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

filename String?
Original filename.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
MIME type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
File size in bytes.
final
type String
Attachment type (image, file, audio, video).
final
url String
URL or path to the attachment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited