ChannelIdentity class

Identifies a channel platform (e.g., 'slack', 'telegram', 'http', 'websocket').

Constructors

ChannelIdentity({required String platform, required String channelId, String? displayName})
const
ChannelIdentity.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

channelId String
Channel-specific identifier (e.g., workspace ID, server ID).
final
displayName String?
Optional display name.
final
hashCode int
The hash code for this object.
no setteroverride
platform String
Platform identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override