ConversationKey class
Unique key for a conversation within a channel.
Constructors
- ConversationKey({required ChannelIdentity channel, required String conversationId, String? userId})
-
const
-
ConversationKey.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- channel → ChannelIdentity
-
Channel identity.
final
- conversationId → String
-
Conversation-specific identifier (e.g., thread ID, DM ID).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String?
-
Optional user identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override