DatasourceAdapter class abstract

Base contract for any datastore backend.

Implementers

Constructors

DatasourceAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Namespace-local instance id (e.g. workspace, main_db).
no setter
kind String
Backend family — fs | sql | nosql | ….
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Release resources / close connections.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() Future<void>
Open / connect. No-op for stateless backends.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited