DbStatement class

One statement within a DbAdapter.tx batch.

Constructors

DbStatement(String statement, {List<Object?> params = const <Object?>[]})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
params → List<Object?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statement → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited