FsStat class

File metadata (fs.stat).

Constructors

FsStat({required String path, required bool exists, required bool isDirectory, int? size, DateTime? modified})
const

Properties

exists bool
final
hashCode int
The hash code for this object.
no setterinherited
isDirectory bool
final
modified DateTime?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited