StubChannelPort class
Stub channel port for testing.
- Implemented types
Constructors
Properties
- capabilities → ChannelCapabilities
-
Capabilities of this channel.
no setteroverride
-
events
→ Stream<
ChannelEvent> -
Stream of incoming events.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → ChannelIdentity
-
Channel identity.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sentResponses
→ List<
ChannelResponse> -
List of sent responses (for testing verification).
final
Methods
-
delete(
String messageId) → Future< void> -
Delete a previously sent message (if supported).
override
-
edit(
String messageId, ChannelResponse response) → Future< void> -
Edit a previously sent message (if supported).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
react(
String messageId, String reaction) → Future< void> -
Add a reaction to a message (if supported).
override
-
send(
ChannelResponse response) → Future< void> -
Send a response to the channel.
override
-
sendTyping(
ConversationKey conversation) → Future< void> -
Send typing indicator (if supported).
override
-
simulateEvent(
ChannelEvent event) → void - Simulate receiving an event (for testing).
-
start(
) → Future< void> -
Start receiving events.
override
-
stop(
) → Future< void> -
Stop receiving events.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited