AnalysisAlert class
Evaluated alert result indicating whether a condition was triggered.
Constructors
- AnalysisAlert({required String alertRuleId, required AnalysisAlertSeverity severity, required DateTime timestamp, required String condition, required dynamic currentValue, required bool triggered, String? actionHook})
- Cannot be const due to dynamic field.
-
AnalysisAlert.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- actionHook → String?
-
Optional action hook URI to invoke if triggered.
final
- alertRuleId → String
-
Identifier of the alert rule that was evaluated.
final
- condition → String
-
Condition expression that was evaluated.
final
- currentValue → dynamic
-
Current value that was tested against the condition.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → AnalysisAlertSeverity
-
Severity of the alert.
final
- timestamp → DateTime
-
Timestamp of the evaluation.
final
- triggered → bool
-
Whether the alert condition was triggered.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited