AnalysisColumnInfo class
Column metadata for an analysis source schema.
Constructors
- AnalysisColumnInfo({required String name, required String type, String? unit})
-
const
-
AnalysisColumnInfo.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Column name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Column data type (string, int, double, bool, datetime).
final
- unit → String?
-
Optional unit for the column values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited