AnalysisDataSet class
Data set returned from a source query.
Constructors
-
AnalysisDataSet({required List<
AnalysisColumnInfo> columns, required List<Map< rows, required int rowCount, AnalysisTimeRange? timeRange, Map<String, dynamic> >String, dynamic> ? metadata}) -
AnalysisDataSet.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
columns
→ List<
AnalysisColumnInfo> -
Column definitions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata about the data set.
final
- rowCount → int
-
Total number of rows.
final
-
rows
→ List<
Map< String, dynamic> > -
Row data as list of maps.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeRange → AnalysisTimeRange?
-
Time range of the data, if temporal.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited