AnalysisFunctionPort class abstract
Contract for pluggable analysis function registration and execution.
Built-in functions:
- descriptive_stats: min, max, avg, std, percentiles
- anomaly_detect: threshold, z-score, IQR, simple EWMA
- event_analysis: frequency count, MTBF, MTTR, state transitions
- time_series_analysis: moving average, trend line
- correlation_regression: correlation coefficient, linear regression
- rule_based_classification: conditional rule-based label assignment
Implementations: mcp_analysis (FunctionCatalog)
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeFunction(
{required String functionName, required Map< String, dynamic> parameters, required AnalysisDataSet data}) → Future<AnalysisFunctionResult> - Execute an analysis function on a data set.
-
getFunctionCatalog(
) → Future< List< AnalysisFunctionInfo> > - List available functions with parameter schemas.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerFunction(
AnalysisFunctionInfo function) → Future< void> - Register a new analysis function.
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterFunction(
String functionName) → Future< void> - Unregister a function.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited