AnalysisInputSource class
Definition of an analysis input source.
Constructors
-
AnalysisInputSource({required AnalysisSourceType sourceType, String? query, Map<
String, dynamic> ? filter, AnalysisTimeRange? timeRange, AnalysisSourceSchema? schema}) - Cannot be const due to Map<String, dynamic> field.
-
AnalysisInputSource.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
filter
→ Map<
String, dynamic> ? -
Optional filter criteria as key-value pairs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → String?
-
Optional query string for selecting data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → AnalysisSourceSchema?
-
Optional schema describing the source structure.
final
- sourceType → AnalysisSourceType
-
Type of the data source.
final
- timeRange → AnalysisTimeRange?
-
Optional time range to restrict input data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited