AnalysisModelArtifact class
Artifact containing a trained or fitted model.
- Inheritance
-
- Object
- AnalysisArtifact
- AnalysisModelArtifact
Constructors
-
AnalysisModelArtifact({required String artifactId, required String name, required AnalysisArtifactProvenance provenance, required Map<
String, dynamic> parameters, required String modelVersion, required Map<String, dynamic> performanceMetrics}) - Cannot be const due to Map<String, dynamic> fields.
-
AnalysisModelArtifact.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- artifactId → String
-
Unique artifact identifier.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelVersion → String
-
Version of the model.
final
- name → String
-
Human-readable artifact name.
finalinherited
-
parameters
→ Map<
String, dynamic> -
Model parameters.
final
-
performanceMetrics
→ Map<
String, dynamic> -
Performance metrics (e.g., accuracy, RMSE).
final
- provenance → AnalysisArtifactProvenance
-
Provenance metadata describing origin and lineage.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AnalysisArtifactType
-
Type of this artifact.
finalinherited
Methods
-
baseToJson(
) → Map< String, dynamic> -
Serialize base fields shared by all artifact types.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON. Subclasses must implement this.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited