AnalysisSpec class
Complete analysis specification describing inputs, transforms, analysis steps, and expected outputs.
Constructors
-
AnalysisSpec({required String specId, required String version, required List<
AnalysisInputSource> inputSources, List<AnalysisTransform> transforms = const [], required List<AnalysisStep> analysisSteps, required List<AnalysisOutputDef> outputs, Map<String, dynamic> parameters = const {}, required AnalysisSpecMetadata metadata}) - Cannot be const due to Map<String, dynamic> field.
-
AnalysisSpec.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
analysisSteps
→ List<
AnalysisStep> -
Analysis computation steps.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputSources
→ List<
AnalysisInputSource> -
Input data sources.
final
- metadata → AnalysisSpecMetadata
-
Specification metadata.
final
-
outputs
→ List<
AnalysisOutputDef> -
Expected output artifact definitions.
final
-
parameters
→ Map<
String, dynamic> -
Global parameters for the analysis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specId → String
-
Unique specification identifier.
final
-
transforms
→ List<
AnalysisTransform> -
Data transformation steps applied before analysis.
final
- version → String
-
Specification version string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited