AnalysisStep class
An individual analysis computation step.
Constructors
-
AnalysisStep({required String function, required Map<
String, dynamic> parameters}) - Cannot be const due to Map<String, dynamic> field.
-
AnalysisStep.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- function → String
-
Analysis function name (descriptive_stats, anomaly_detect,
event_analysis, etc.).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
→ Map<
String, dynamic> -
Function-specific parameters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited