AnalysisTransform class
A data transformation step applied before analysis.
Constructors
-
AnalysisTransform({required String name, required Map<
String, dynamic> parameters}) - Cannot be const due to Map<String, dynamic> field.
-
AnalysisTransform.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Transform name (filter, resample, join, clip, fillna, sort, convert).
final
-
parameters
→ Map<
String, dynamic> -
Transform-specific parameters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited