AppraisalMetadata class
Metadata about the appraisal computation.
Constructors
-
AppraisalMetadata({required DateTime computedAt, int durationMs = 0, Map<
String, int> sourceCounts = const {}, List<String> missingMetrics = const [], List<String> ? lowConfidenceMetrics, List<String> metricsRequiringEvidence = const [], List<String> warnings = const []}) -
const
-
AppraisalMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- computedAt → DateTime
-
When computation was performed.
final
- duration → Duration
-
Get duration as Duration object.
no setter
- durationMs → int
-
Computation duration in milliseconds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lowConfidenceMetrics
→ List<
String> ? -
Metrics with low confidence (< 0.5).
final
-
metricsRequiringEvidence
→ List<
String> -
Metrics that triggered require_evidence per 9.3 step 4.
final
-
missingMetrics
→ List<
String> -
Metrics that couldn't be computed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceCounts
→ Map<
String, int> -
Count of sources used by type.
final
-
warnings
→ List<
String> -
Warnings during computation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited