ApprovalPolicy enum
Approval policy determines how approvals are collected.
Values
- anyOne → const ApprovalPolicy
-
Any single approver can approve.
- allRequired → const ApprovalPolicy
-
All approvers must approve.
- majority → const ApprovalPolicy
-
Majority of approvers must approve.
- sequential → const ApprovalPolicy
-
Approvers must approve in sequence.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → ApprovalPolicy
Constants
-
values
→ const List<
ApprovalPolicy> - A constant List of the values in this enum, in order of their declaration.