ApprovalResult class
Result of an approval request.
Constructors
-
ApprovalResult({required String approvalId, required ApprovalStatus status, String? approverId, String? reason, DateTime? decidedAt, List<
ApprovalDecision> decisions = const []}) -
const
-
ApprovalResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- approvalId → String
-
Approval ID for tracking.
final
- approverId → String?
-
ID of the approver who made the decision (if decided).
final
- decidedAt → DateTime?
-
When the decision was made.
final
-
decisions
→ List<
ApprovalDecision> -
List of all approval decisions (for multi-approver policies).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isApproved → bool
-
Check if approved.
no setter
- isPending → bool
-
Check if still pending.
no setter
- isRejected → bool
-
Check if rejected.
no setter
- reason → String?
-
Reason provided by the approver.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ApprovalStatus
-
Current status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited