AsrOptions class
ASR processing options.
Constructors
Properties
- enableDiarization → bool
-
Whether to enable speaker diarization.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String
-
Language code (e.g., 'en', 'ko', 'ja').
final
- maxSpeakers → int?
-
Maximum number of speakers to detect (for diarization).
final
- modelSize → String?
-
Model size hint (tiny, base, small, medium, large).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- translate → bool
-
Whether to translate to English.
final
- wordTimestamps → bool
-
Whether to include word-level timestamps.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited