Port for ASR operations.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isAvailable(
) → Future< bool> - Check if the ASR engine is available.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportedLanguages(
) → Future< List< String> > - Get supported languages.
-
toString(
) → String -
A string representation of this object.
inherited
-
transcribe(
Stream< List< audioData, AsrOptions options) → Future<int> >AsrResult> - Transcribe audio stream.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited