AsrSegment class
Single transcription segment.
Constructors
Properties
- confidence → double
-
Confidence score.
final
- endTime → Duration
-
End time.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speakerId → String?
-
Speaker identifier for diarization (null if not supported/enabled).
final
- startTime → Duration
-
Start time.
final
- text → String
-
Segment text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited