BundleSource class
Bundle source information.
Constructors
-
BundleSource({required SourceType type, required dynamic source, Map<
String, dynamic> metadata = const {}}) -
const
- BundleSource.file(String path)
-
Create a file source.
factory
-
BundleSource.json(Map<
String, dynamic> json) -
Create a JSON source.
factory
- BundleSource.string(String content)
-
Create a string source.
factory
- BundleSource.url(String url)
-
Create a URL source.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Source metadata.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → dynamic
-
Source location or data.
final
- type → SourceType
-
Source type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited