ChannelDeliveryResult class
Delivery result for a specific channel.
Constructors
-
ChannelDeliveryResult({required NotificationChannel channel, required bool success, DateTime? deliveredAt, String? error, Map<
String, dynamic> response = const {}}) -
const
-
ChannelDeliveryResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- channel → NotificationChannel
-
Channel used.
final
- deliveredAt → DateTime?
-
When delivery occurred.
final
- error → String?
-
Error if failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
response
→ Map<
String, dynamic> -
Channel-specific response data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether delivery succeeded.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited