ClaimStatus enum
Verification state of the claim.
Values
- pending → const ClaimStatus
- verifying → const ClaimStatus
- supported → const ClaimStatus
- unsupported → const ClaimStatus
- conflicting → const ClaimStatus
- partiallySupported → const ClaimStatus
- unverifiable → const ClaimStatus
- speculation → const ClaimStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → ClaimStatus
Constants
-
values
→ const List<
ClaimStatus> - A constant List of the values in this enum, in order of their declaration.