ClaimType enum
Semantic type of the claim content.
Values
- fact → const ClaimType
- date → const ClaimType
- amount → const ClaimType
- quantity → const ClaimType
- category → const ClaimType
- entity → const ClaimType
- relation → const ClaimType
- temporal → const ClaimType
- causal → const ClaimType
- comparative → const ClaimType
- quantitative → const ClaimType
- conclusion → const ClaimType
- recommendation → const ClaimType
- speculation → const ClaimType
- observation → const ClaimType
- prediction → const ClaimType
- opinion → const ClaimType
- hypothetical → const ClaimType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → ClaimType