ClaimValidationEntry class
Single-claim validation entry.
Constructors
-
ClaimValidationEntry({required String claimId, required ClaimStatus status, List<
String> supportingRefs = const [], String? conflictReason}) -
const
Properties
- claimId → String
-
Claim identifier.
final
- conflictReason → String?
-
Conflict reason if applicable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ClaimStatus
-
Validation status.
final
-
supportingRefs
→ List<
String> -
Supporting evidence references.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited