ClaimValidationReport class
Aggregate validation report.
Constructors
-
ClaimValidationReport({required bool passed, required List<
ClaimValidationEntry> entries, List<String> issues = const []}) -
const
Properties
-
entries
→ List<
ClaimValidationEntry> -
Per-claim status.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
String> -
Aggregate issues discovered.
final
- passed → bool
-
Whether all claims passed validation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited