CollectionStoragePort class abstract
Abstract collection-based storage port.
Provides collection-based storage with query support. Unlike KvStoragePort (key-value), this port organizes data into collections.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String collection, String id) → Future< void> - Delete an item from a collection.
-
exists(
String collection, String id) → Future< bool> - Check if an item exists.
-
get(
String collection, String id) → Future< Map< String, dynamic> ?> - Get an item by collection and ID.
-
listIds(
String collection) → Future< List< String> > - List all IDs in a collection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String collection, QueryFilter filter) → Future< List< Map< >String, dynamic> > - Query items in a collection.
-
save(
String collection, String id, Map< String, dynamic> data) → Future<void> - Save an item to a collection.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited