Command class
Command to execute on a device.
Constructors
Properties
- action → String
-
Action to perform.
final
-
args
→ Map<
String, dynamic> -
Arguments for the action.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata.
final
- priority → int?
-
Execution priority (lower = higher priority).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
Target resource or channel URI.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited