ContextBundleRequest class
Request for ContextBundlePort.buildContextBundle.
Constructors
- ContextBundleRequest({required String query, required String workspaceId, DateTime? asOf, Period? period, String? policyVersion, ContextBudget? budget})
-
const
Properties
- asOf → DateTime?
-
Point in time for the query.
final
- budget → ContextBudget?
-
Budget constraints.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- period → Period?
-
Period filter.
final
- policyVersion → String?
-
Policy version.
final
- query → String
-
Natural-language query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workspaceId → String
-
Workspace identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited