DateRange class
Helper class for resolved date ranges.
Properties
Methods
-
contains(
DateTime date) → bool - Check if a date is within this range (inclusive).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override