DecisionAction enum
Actions that can be recommended by a decision policy.
- Inheritance
- Available extensions
Values
- proceed → const DecisionAction
-
Continue normally.
- proceedWithCaution → const DecisionAction
-
Continue with extra care.
- hold → const DecisionAction
-
Wait for more information.
- question → const DecisionAction
-
Ask clarifying questions.
- escalate → const DecisionAction
-
Request human/expert input.
- reject → const DecisionAction
-
Do not proceed.
- defer → const DecisionAction
-
Postpone decision.
- custom → const DecisionAction
-
Application-specific action.
Properties
- allowsProceeding → bool
-
Available on DecisionAction, provided by the DecisionActionExtension extension
Whether this action allows proceeding.no setter - blocksProceeding → bool
-
Available on DecisionAction, provided by the DecisionActionExtension extension
Whether this action blocks proceeding.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - requiresHuman → bool
-
Available on DecisionAction, provided by the DecisionActionExtension extension
Whether this action requires human intervention.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonName(
) → String -
Available on DecisionAction, provided by the DecisionActionExtension extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DecisionAction> - A constant List of the values in this enum, in order of their declaration.