DecisionModifier class
Additional modifier for a decision.
Constructors
-
DecisionModifier({required ModifierType type, Map<
String, dynamic> ? config}) -
const
- DecisionModifier.addDisclaimer({required String text, String position = 'start'})
-
Create add_disclaimer modifier.
factory
-
DecisionModifier.fromJson(Map<
String, dynamic> json) -
factory
- DecisionModifier.log({String level = 'info'})
-
Create log modifier.
factory
-
DecisionModifier.notify({required List<
String> channels, required List<String> recipients, String? template, String urgency = 'normal'}) -
Create notify modifier.
factory
- DecisionModifier.requireApproval({required String approverRole, String? expiresIn})
-
Create require_approval modifier.
factory
-
DecisionModifier.requireEvidence({int minSources = 1, List<
String> ? evidenceTypes}) -
Create require_evidence modifier.
factory
Properties
-
config
→ Map<
String, dynamic> ? -
Modifier configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ModifierType
-
Modifier type.
final
Methods
-
getConfig<
T> (String key) → T? - Get config value with type cast.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited