DirectionalAttitude class
Fundamental posture toward a domain.
- Annotations
-
- @immutable
Constructors
-
DirectionalAttitude({required String id, required AttitudeDomain domain, required String posture, required List<
String> behavioralImplications}) -
const
-
DirectionalAttitude.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
behavioralImplications
→ List<
String> -
Concrete behavioral effects.
final
- domain → AttitudeDomain
-
Domain of attitude applicability.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier.
final
- posture → String
-
Descriptive statement of the posture.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited