EmergencyStopRequest class
Request to perform an emergency stop.
Constructors
- EmergencyStopRequest({String? deviceId, required String reason, required String actorId})
-
const
-
EmergencyStopRequest.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- actorId → String
-
Actor who initiated the stop.
final
- deviceId → String?
-
Specific device to stop (null = all devices).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String
-
Reason for the emergency stop.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited