EntityQuery class
Query descriptor for EntitiesPort.queryEntities.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Maximum results.
final
- nameContains → String?
-
Name contains filter.
final
-
propertyFilters
→ Map<
String, dynamic> ? -
Property filters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ List<
String> ? -
Entity types to include.
final
- workspaceId → String
-
Workspace identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited