EnvelopeMeta class
Envelope metadata including capture time and source address.
Constructors
- EnvelopeMeta({required DateTime capturedAt, required String sourceAddress, int? sequenceNumber, ChunkMeta? chunk})
-
const
-
EnvelopeMeta.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- capturedAt → DateTime
-
When the data was captured.
final
- chunk → ChunkMeta?
-
Chunk metadata for multi-part payloads.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceNumber → int?
-
Sequence number for ordering.
final
- sourceAddress → String
-
Source address or identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited