ErrorHandler class
Error handler definition.
Constructors
-
ErrorHandler({required String name, List<
String> patterns = const [], Map<String, dynamic> action = const {}, bool continueFlow = false}) -
const
-
ErrorHandler.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
action
→ Map<
String, dynamic> -
Handler action.
final
- continueFlow → bool
-
Whether to continue after handling.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Handler name.
final
-
patterns
→ List<
String> -
Error patterns to match.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited