Ethos class
Root philosophy definition containing all components.
- Annotations
-
- @immutable
Constructors
-
Ethos({required String id, required String name, required List<
ValuePriority> valuePriorities, required List<Prohibition> prohibitions, List<JudgmentCriterion> judgmentCriteria = const [], List<DirectionalAttitude> directionalAttitudes = const [], required EthosMetadata metadata, List<EthosScope> ? scopes}) -
const
-
Ethos.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
directionalAttitudes
→ List<
DirectionalAttitude> -
Fundamental postures toward domains (uncertainty, failure, conflict).
final
-
hardProhibitions
→ List<
Prohibition> -
Get all hard prohibitions.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier.
final
-
judgmentCriteria
→ List<
JudgmentCriterion> -
Conditional decision rules.
final
- metadata → EthosMetadata
-
Version, author, timestamps, context.
final
- name → String
-
Human-readable name.
final
-
prohibitions
→ List<
Prohibition> -
Absolute boundaries with severity classification.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
EthosScope> ? -
Domain-specific applicability scopes.
final
-
softProhibitions
→ List<
Prohibition> -
Get all soft prohibitions.
no setter
- topPriority → ValuePriority?
-
Get the highest-priority ValuePriority (rank 1).
no setter
-
valuePriorities
→ List<
ValuePriority> -
Ordered value priorities (rank 1 = highest).
final
Methods
-
isApplicableTo(
String domain) → bool - Check if this Ethos is scoped to a specific domain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited