EvidencePort class abstract
Port for evidence extraction operations.
Used by the fact graph to extract and evaluate evidence fragments.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
classifyFragment(
String fragment) → Future< String> - Classify fragment type.
-
computeConfidence(
String fragment) → Future< double> - Compute confidence score for a fragment.
-
extractFragments(
String content, String mimeType) → Future< List< EvidenceFragment> > - Extract fragments from content.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited