ExpressionPort class abstract
Port for expression/template formatting operations.
Used by the profile system to render templates with variables and apply expression styles.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
extractVariables(
String template) → List< String> - Extract variable names from template.
-
format(
String template, Map< String, dynamic> variables) → String - Format a template with variables.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
ExpressionStyle style, Map< String, dynamic> data) → String - Render a style onto data (optional capability — default throws).
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String template) → bool - Validate a template.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited