FeedbackEvent class
Action result feedback for philosophy evolution.
- Annotations
-
- @immutable
Constructors
-
FeedbackEvent({required String id, required String actionId, required String ethosId, String? valuePriorityId, String? judgmentCriterionId, required FeedbackOutcome outcome, required double outcomeScore, String? outcomeDescription, Map<
String, dynamic> ? contextSnapshot, DateTime? occurredAt}) -
FeedbackEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actionId → String
-
Action that produced the outcome.
final
-
contextSnapshot
→ Map<
String, dynamic> ? -
Context snapshot at time of action.
final
- ethosId → String
-
Ethos that was active.
final
- hasCriterionLink → bool
-
Whether this feedback is linked to a specific judgment criterion.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasValuePriorityLink → bool
-
Whether this feedback is linked to a specific value priority.
no setter
- id → String
-
Unique identifier.
final
- isNegative → bool
-
Whether this is a negative outcome.
no setter
- isPositive → bool
-
Whether this is a positive outcome.
no setter
- judgmentCriterionId → String?
-
Which criterion was applied.
final
- occurredAt → DateTime
-
When the outcome occurred.
final
- outcome → FeedbackOutcome
-
Outcome classification.
final
- outcomeDescription → String?
-
Human-readable outcome description.
final
- outcomeScore → double
-
Outcome score (-1.0 to 1.0).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valuePriorityId → String?
-
Which value priority was applied.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited