FlowTrigger class
Flow trigger definition.
Constructors
-
FlowTrigger({required TriggerType type, Map<
String, dynamic> config = const {}, String? condition}) -
const
-
FlowTrigger.fromJson(Map<
String, dynamic> json) -
factory
Properties
- condition → String?
-
Trigger condition expression.
final
-
config
→ Map<
String, dynamic> -
Trigger configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TriggerType
-
Trigger type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited