FormChartBlock class
A chart visualization block.
Constructors
-
FormChartBlock({required String blockId, required int index, Map<
String, dynamic> ? style, required String chartType, List data = const [], String? title, FormAxisConfig? xAxis, FormAxisConfig? yAxis, String? unit}) -
FormChartBlock.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- blockId → String
-
Unique block identifier.
finalinherited
- chartType → String
-
Chart type (e.g., 'bar', 'line', 'pie').
final
- data → List
-
Chart data series.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Block ordering index.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
style
→ Map<
String, dynamic> ? -
Optional style properties.
finalinherited
- title → String?
-
Optional chart title.
final
- type → FormBlockType
-
Type of this block.
finalinherited
- unit → String?
-
Unit label for the chart data.
final
- xAxis → FormAxisConfig?
-
X-axis configuration.
final
- yAxis → FormAxisConfig?
-
Y-axis configuration.
final
Methods
-
baseToJson(
) → Map< String, dynamic> -
Serialize common base fields to a map.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited