FormDataBinding class
A data binding that connects a form field to a data source.
Constructors
-
FormDataBinding({required String bindingId, required String fieldPath, required String dataPath, required FormDataSourceType source, String? sourceQuery, String? toolName, Map<
String, dynamic> ? toolParams, String? transform, bool required = false, dynamic defaultValue, bool isFilled = false, DateTime? filledAt}) -
FormDataBinding.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- bindingId → String
-
Unique binding identifier.
final
- dataPath → String
-
Path to the data in the source.
final
- defaultValue → dynamic
-
Default value if the binding cannot be resolved.
final
- fieldPath → String
-
Path to the field in the form document.
final
- filledAt → DateTime?
-
When the binding was filled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFilled → bool
-
Whether the binding has been filled with data.
final
- required → bool
-
Whether this binding is required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → FormDataSourceType
-
Type of data source.
final
- sourceQuery → String?
-
Query expression for the source.
final
- toolName → String?
-
Tool name for tool-based sources.
final
-
toolParams
→ Map<
String, dynamic> ? -
Parameters for tool-based sources.
final
- transform → String?
-
Transform expression to apply to the data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited