FormFieldBlock class
An interactive form field block.
Constructors
Properties
- blockId → String
-
Unique block identifier.
finalinherited
-
constraints
→ Map<
String, dynamic> ? -
Constraints for the field value.
final
- fieldName → String
-
Field name for data binding.
final
- fieldType → String
-
Field type (e.g., 'text', 'number', 'date', 'select').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Block ordering index.
finalinherited
- options → List?
-
Options for select/radio/checkbox fields.
final
- placeholder → String?
-
Placeholder text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
style
→ Map<
String, dynamic> ? -
Optional style properties.
finalinherited
- type → FormBlockType
-
Type of this block.
finalinherited
Methods
-
baseToJson(
) → Map< String, dynamic> -
Serialize common base fields to a map.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited