FormFontPolicy class
Font policy configuration for form layout.
Constructors
- FormFontPolicy({required String defaultFont, required double defaultSize, required double headingSize, required double bodySize, required double minSize})
-
const
-
FormFontPolicy.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- bodySize → double
-
Body text font size in points.
final
- defaultFont → String
-
Default font family name.
final
- defaultSize → double
-
Default font size in points.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headingSize → double
-
Heading font size in points.
final
- minSize → double
-
Minimum font size in points.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited