FormLayoutPolicy class
Layout policy for form document rendering.
Constructors
- FormLayoutPolicy({required FormPageSize pageSize, required FormMargins margins, String fontFamily = 'sans-serif', required FormFontPolicy fontPolicy, int gridColumns = 12, int? maxTableRows, int? maxLineLength, bool autoWrap = true, bool autoScale = false})
-
const
-
FormLayoutPolicy.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- autoScale → bool
-
Whether automatic scaling is enabled.
final
- autoWrap → bool
-
Whether automatic text wrapping is enabled.
final
- fontFamily → String
-
Primary font family.
final
- fontPolicy → FormFontPolicy
-
Font policy configuration.
final
- gridColumns → int
-
Number of grid columns for layout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- margins → FormMargins
-
Page margins.
final
- maxLineLength → int?
-
Maximum line length in characters.
final
- maxTableRows → int?
-
Maximum number of rows in tables.
final
- pageSize → FormPageSize
-
Page size configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited