FormRepeatableBlock class
A repeatable block that generates multiple instances from a template.
Constructors
Properties
- blockId → String
-
Unique block identifier.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Block ordering index.
finalinherited
- itemsBinding → String?
-
Data binding path for the items collection.
final
-
itemTemplate
→ List<
FormBlock> -
Template blocks to repeat for each item.
Each item instance consists of all blocks in this list.
final
- maxItems → int?
-
Maximum number of items.
final
- minItems → int?
-
Minimum number of items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
style
→ Map<
String, dynamic> ? -
Optional style properties.
finalinherited
- type → FormBlockType
-
Type of this block.
finalinherited
Methods
-
baseToJson(
) → Map< String, dynamic> -
Serialize common base fields to a map.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited