FormSchema class
Schema definition for form validation.
Constructors
-
FormSchema({List<
FormSchemaField> fields = const [], List<FormSchemaRule> rules = const [], bool strict = false}) -
const
-
FormSchema.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
fields
→ List<
FormSchemaField> -
Field definitions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rules
→ List<
FormSchemaRule> -
Validation rules.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strict → bool
-
Whether strict mode is enabled (reject unknown fields).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited