FormSchemaField class
A field definition within a form schema.
Constructors
- FormSchemaField({required String name, required String type, bool required = false, String? label, String? placeholder, String? format, dynamic minValue, dynamic maxValue, String? pattern, List? enumValues, String? description, bool sensitive = false})
-
FormSchemaField.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- description → String?
-
Field description.
final
- enumValues → List?
-
Allowed enumeration values.
final
- format → String?
-
Expected format (e.g., 'email', 'url', 'date-time').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
Display label.
final
- maxValue → dynamic
-
Maximum value (for numeric types).
final
- minValue → dynamic
-
Minimum value (for numeric types).
final
- name → String
-
Field name.
final
- pattern → String?
-
Regular expression pattern for validation.
final
- placeholder → String?
-
Placeholder text.
final
- required → bool
-
Whether the field is required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitive → bool
-
Whether this field contains sensitive data.
final
- type → String
-
Field data type (e.g., 'string', 'number', 'boolean', 'date').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited