FormSchemaRule class
A validation rule within a form schema.
Constructors
- FormSchemaRule({required String ruleId, required String description, required String expression, String? errorMessage})
-
const
-
FormSchemaRule.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- description → String
-
Human-readable description of the rule.
final
- errorMessage → String?
-
Error message to display when the rule fails.
final
- expression → String
-
Expression to evaluate for validation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ruleId → String
-
Unique rule identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited