FormTableBlock class
A table content block with columns and rows.
Constructors
-
FormTableBlock({required String blockId, required int index, Map<
String, dynamic> ? style, required List<FormTableColumn> columns, List<FormTableRow> rows = const [], bool headerRepeat = false, int? maxRows, String? unit}) -
FormTableBlock.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- blockId → String
-
Unique block identifier.
finalinherited
-
columns
→ List<
FormTableColumn> -
Table column definitions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerRepeat → bool
-
Whether the header row repeats on each page.
final
- index → int
-
Block ordering index.
finalinherited
- maxRows → int?
-
Maximum number of rows allowed.
final
-
rows
→ List<
FormTableRow> -
Table row data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
style
→ Map<
String, dynamic> ? -
Optional style properties.
finalinherited
- type → FormBlockType
-
Type of this block.
finalinherited
- unit → String?
-
Unit label for the table data.
final
Methods
-
baseToJson(
) → Map< String, dynamic> -
Serialize common base fields to a map.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited