FormTableColumn class
Column definition for a table block.
Constructors
- FormTableColumn({required String id, required String title, required String type, double? width, String? alignment})
-
const
-
FormTableColumn.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- alignment → String?
-
Optional column alignment ('left', 'center', 'right').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique column identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Column display title.
final
- type → String
-
Data type of the column (e.g., 'string', 'number', 'date').
final
- width → double?
-
Optional column width.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited