FormTemplate class
Form template definition.
Constructors
-
FormTemplate({required String templateId, required String version, required String name, String? description, required FormSchema schema, required FormLayoutPolicy layoutPolicy, List<
FormSection> defaultSections = const [], String? locale, List<String> ? components, Map<String, String> ? i18nStrings, FormTemplateManifest? manifest}) -
FormTemplate.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
components
→ List<
String> ? -
Optional list of component identifiers used by the template.
final
-
defaultSections
→ List<
FormSection> -
Default sections for the template.
final
- description → String?
-
Optional description of the template.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
i18nStrings
→ Map<
String, String> ? -
Optional internationalisation key-value pairs.
final
- layoutPolicy → FormLayoutPolicy
-
Layout policy for rendering the template.
final
- locale → String?
-
Optional locale identifier (e.g., 'en', 'ko').
final
- manifest → FormTemplateManifest?
-
Optional manifest with dependencies and compatibility info.
final
- name → String
-
Human-readable template name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → FormSchema
-
Schema defining the template fields and validation.
final
- templateId → String
-
Unique template identifier.
final
- version → String
-
Semantic version string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited