HedgingConfig class
Configuration for hedging language.
Constructors
- HedgingConfig({HedgingLevel level = HedgingLevel.none, HedgingPhrases? phrases, HedgingPosition position = HedgingPosition.inline})
-
const
-
HedgingConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → HedgingLevel
-
Hedging level.
final
- phrases → HedgingPhrases?
-
Custom hedging phrases.
final
- position → HedgingPosition
-
Where to apply hedging.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited