InMemoryKvStoragePort class
In-memory KV storage for testing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> -
Clear all data.
override
-
exists(
String key) → Future< bool> -
Check if key exists.
override
-
get(
String key) → Future -
Get a value.
override
-
keys(
{String? prefix}) → Future< List< String> > -
List keys with optional prefix.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Future< void> -
Remove a value.
override
-
set(
String key, dynamic value) → Future< void> -
Set a value.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited