IngestPorts class
Bundle of all ingest-related ports.
Constructors
- IngestPorts({OcrPort? ocr, AsrPort? asr, VisionPort? vision, BinaryStoragePort? storage, LlmPort? llm})
-
const
- IngestPorts.stubs()
-
Create with stubs for testing.
factory
Properties
- asr → AsrPort?
-
ASR port for audio transcription.
final
-
hasAsr
→ Future<
bool> -
Check if ASR is available.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLlm → bool
-
Check if LLM is available.
no setter
-
hasOcr
→ Future<
bool> -
Check if OCR is available.
no setter
- hasStorage → bool
-
Check if storage is available.
no setter
-
hasVision
→ Future<
bool> -
Check if Vision is available.
no setter
- llm → LlmPort?
-
LLM port for semantic processing.
final
- ocr → OcrPort?
-
OCR port for text extraction from images.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → BinaryStoragePort?
-
Storage port for binary assets.
final
- vision → VisionPort?
-
Vision port for image analysis.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const IngestPorts
- Empty ports (no capabilities).