Interlock class
Interlock that must be satisfied before an action proceeds.
Constructors
- Interlock({required String uri, required InterlockCondition condition, required InterlockAction action})
-
const
-
Interlock.fromJson(Map<
String, dynamic> json) -
factory
Properties
- action → InterlockAction
-
Action to take when the interlock condition is met.
final
- condition → InterlockCondition
-
Condition to evaluate against the interlock target.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
URI of the device or resource to check.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited