IoAuditRecord class
Immutable record of an auditable IO operation.
Constructors
-
IoAuditRecord({required String id, required IoAuditType type, required String actorId, required String actorRole, Command? command, required String deviceId, PolicyDecision? policyDecision, PolicyTrace? policyTrace, CommandStatus? resultStatus, required DateTime requestedAt, DateTime? executedAt, DateTime? completedAt, Map<
String, dynamic> ? stateBefore, Map<String, dynamic> ? stateAfter, Map<String, dynamic> ? metadata}) -
IoAuditRecord.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- actorId → String
-
Identity of the actor who initiated the operation.
final
- actorRole → String
-
Role of the actor (e.g., "skill", "operator", "system").
final
- command → Command?
-
Command that was executed, if applicable.
final
- completedAt → DateTime?
-
Timestamp when execution completed.
final
- deviceId → String
-
Target device identifier.
final
- executedAt → DateTime?
-
Timestamp when execution began.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique audit record identifier.
final
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata for the audit record.
final
- policyDecision → PolicyDecision?
-
Policy decision for this operation, if applicable.
final
- policyTrace → PolicyTrace?
-
Full policy evaluation trace, if applicable.
final
- requestedAt → DateTime
-
Timestamp when the operation was requested.
final
- resultStatus → CommandStatus?
-
Result status of the command execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateAfter
→ Map<
String, dynamic> ? -
Device state snapshot after the operation.
final
-
stateBefore
→ Map<
String, dynamic> ? -
Device state snapshot before the operation.
final
- type → IoAuditType
-
Type of auditable operation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited