JudgmentCriterion class
Conditional decision rule with preferred action.
- Annotations
-
- @immutable
Constructors
-
JudgmentCriterion({required String id, required List<
String> conditions, required String preferredAction, String? requiredValidation, String? fallbackStrategy}) -
const
-
JudgmentCriterion.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
conditions
→ List<
String> -
Expression-language conditions.
final
- fallbackStrategy → String?
-
Fallback if preferred action fails.
final
- hasFallback → bool
-
Whether this criterion has a fallback.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier.
final
- preferredAction → String
-
What to do when conditions match.
final
- requiredValidation → String?
-
Additional validation needed.
final
- requiresValidation → bool
-
Whether additional validation is required.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited