MetricValue class
Metric value.
Constructors
-
MetricValue({required double value, required DateTime timestamp, double? confidence, Map<
String, dynamic> ? metadata}) -
const
-
MetricValue.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- confidence → double?
-
Confidence score (0.0-1.0).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp.
final
- value → double
-
Numeric value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited