Port for OCR operations.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isAvailable(
) → Future< bool> - Check if the OCR engine is available.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recognize(
Stream< List< imageData, OcrOptions options) → Future<int> >OcrResult> - Recognize text from image bytes.
-
supportedLanguages(
) → Future< List< String> > - Get supported languages.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited