PayloadEnvelope class
Envelope wrapping a typed payload with URI and metadata.
Constructors
- PayloadEnvelope({required String uri, required PayloadKind kind, required TypedPayload payload, required EnvelopeMeta meta})
-
PayloadEnvelope.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → PayloadKind
-
Kind of payload.
final
- meta → EnvelopeMeta
-
Envelope metadata.
final
- payload → TypedPayload
-
The typed payload data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
Resource URI (e.g., io://deviceId/ch/1/waveform).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited