PhilosophyEvaluationContext class
Context for philosophy evaluation.
Named PhilosophyEvaluationContext to avoid conflict with the expression language's EvaluationContext.
- Annotations
-
- @immutable
Constructors
-
PhilosophyEvaluationContext({required String contextId, Map<
String, dynamic> facts = const {}, Map<String, double> metrics = const {}, String? proposedAction, String? proposedOutput, Map<String, dynamic> ? profileState, Map<String, dynamic> ? stateWeighting, DateTime? evaluatedAt}) -
PhilosophyEvaluationContext.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contextId → String
-
Context identifier.
final
- evaluatedAt → DateTime
-
Evaluation timestamp.
final
-
facts
→ Map<
String, dynamic> -
Relevant facts from FactGraph.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasProfileState → bool
-
Whether this context has profile state for tension detection.
no setter
- hasProposedOutput → bool
-
Whether this context has a proposed output to check.
no setter
-
metrics
→ Map<
String, double> -
Relevant metrics.
final
-
profileState
→ Map<
String, dynamic> ? -
Current profile state (for tension detection).
final
- proposedAction → String?
-
Action/output to evaluate (for prohibition checks).
final
- proposedOutput → String?
-
Generated output to evaluate (post-generation).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateWeighting
→ Map<
String, dynamic> ? -
Current dynamic state weights (for intensity adjustment).
final
Methods
-
getFact(
String key) → dynamic - Get a fact value by key.
-
getMetric(
String key) → double? - Get a metric value by key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited