PhilosophyGuidance class
Result of evaluating an Ethos against a context.
- Annotations
-
- @immutable
Constructors
-
PhilosophyGuidance({ValuePriority? valuePriorityApplied, required ProhibitionCheckResult prohibitionChecks, List<
MatchedCriterion> matchedCriteria = const [], DirectionalAttitude? directionalAttitude, required String recommendedAction, required double confidence, required String explanation, required bool prohibitionViolated}) -
const
-
PhilosophyGuidance.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowsProceeding → bool
-
Whether this guidance allows proceeding.
no setter
- confidence → double
-
Confidence score (0.0-1.0).
final
- directionalAttitude → DirectionalAttitude?
-
Resolved directional attitude.
final
- explanation → String
-
Human-readable explanation.
final
- hasConflicts → bool
-
Whether this guidance has conflict annotations.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matchedCriteria
→ List<
MatchedCriterion> -
Applicable judgment criteria.
final
- prohibitionChecks → ProhibitionCheckResult
-
Pass/fail for all prohibitions.
final
- prohibitionViolated → bool
-
Whether any hard prohibition was violated.
final
- recommendedAction → String
-
What action to take.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valuePriorityApplied → ValuePriority?
-
Which value priority was invoked.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited