PolicyTrace class
Trace of policy evaluation for a command.
Constructors
-
PolicyTrace({required String commandId, String? ruleId, required DateTime evaluatedAt, List<
ConditionEvaluation> conditions = const [], required Decision finalDecision, String? finalNotes}) -
const
-
PolicyTrace.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- commandId → String
-
Command identifier that was evaluated.
final
-
conditions
→ List<
ConditionEvaluation> -
Individual condition evaluations.
final
- evaluatedAt → DateTime
-
When the policy was evaluated.
final
- finalDecision → Decision
-
Final decision after all conditions.
final
- finalNotes → String?
-
Notes about the final decision.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ruleId → String?
-
Rule identifier that produced the final decision.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited