ProfileSummaryResult class
Evaluation-level profile summary result.
Constructors
Properties
- confidence → double
-
Confidence score.
final
-
dimensionScores
→ Map<
String, double> -
Dimension scores (dimension ID → normalized score).
final
- entityId → String
-
Entity identifier.
final
- generatedAt → DateTime
-
Generation timestamp.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- narrative → String
-
Summary content (narrative form).
final
- period → Period?
-
Period covered.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited