ProhibitionCheckRequest class
Request to check prohibitions.
- Annotations
-
- @immutable
Constructors
-
ProhibitionCheckRequest({String? proposedAction, String? proposedOutput, Map<
String, dynamic> context = const {}, DateTime? requestedAt}) -
ProhibitionCheckRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
context
→ Map<
String, dynamic> -
Additional context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
At least one of proposedAction or proposedOutput must be provided.
no setter
- proposedAction → String?
-
Action description to check.
final
- proposedOutput → String?
-
Output text to check.
final
- requestedAt → DateTime
-
Request timestamp.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited