QueryFilter class
Query filter for collection storage.
Constructors
Properties
-
conditions
→ Map<
String, dynamic> -
Filter conditions.
final
- descending → bool
-
Whether to order descending.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Maximum number of results.
final
- offset → int?
-
Offset for pagination.
final
- orderBy → String?
-
Field to order by.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const QueryFilter
- Empty filter.