ReadTiming class
Timing information for a read operation.
Constructors
- ReadTiming({required Duration total, Duration? fastest, Duration? slowest})
-
ReadTiming.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- fastest → Duration?
-
Fastest individual read.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slowest → Duration?
-
Slowest individual read.
final
- total → Duration
-
Total time for the read operation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited