RegistryEvent class
Event emitted by the registry when device or adapter state changes.
Constructors
- RegistryEvent({required RegistryEventType type, required String deviceId, String? adapterId, required DateTime timestamp})
-
const
-
RegistryEvent.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- adapterId → String?
-
Identifier of the adapter involved (if applicable).
final
- deviceId → String
-
Identifier of the device involved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the event occurred.
final
- type → RegistryEventType
-
Type of the registry event.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited