ResolutionOption class
Available resolution option for a tension.
- Annotations
-
- @immutable
Constructors
- ResolutionOption({required ResolutionStrategy strategy, required String description, required double estimatedConfidence})
-
const
-
ResolutionOption.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
Description of this option.
final
- estimatedConfidence → double
-
Expected confidence of this resolution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → ResolutionStrategy
-
Strategy for this option.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited