RetrievalResult class
Retrieval result.
Constructors
-
RetrievalResult({required List<
RetrievedPassage> passages, Map<String, dynamic> ? metadata, int? totalMatches}) -
const
-
RetrievalResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether any passages were found.
no setter
- isNotEmpty → bool
-
Whether passages were found.
no setter
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata.
final
-
passages
→ List<
RetrievedPassage> -
Retrieved passages.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalMatches → int?
-
Total number of matches (may be greater than passages.length).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited