RetrievedPassage class
Retrieved passage.
Constructors
-
RetrievedPassage({required String id, required String content, required double score, String? sourceId, String? sourceUri, PassagePosition? position, Map<
String, dynamic> ? metadata}) -
const
-
RetrievedPassage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- content → String
-
Passage content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Passage identifier.
final
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata.
final
- position → PassagePosition?
-
Position in source document.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
Relevance score.
final
- sourceId → String?
-
Source document ID.
final
- sourceUri → String?
-
Source URI.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited