RetrieverInfo class
Retriever information.
Constructors
-
RetrieverInfo({required String id, required String name, required String type, required List<
String> sourceRefs, String? description}) -
const
-
RetrieverInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
Description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Retriever identifier.
final
- name → String
-
Retriever name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceRefs
→ List<
String> -
Source references.
final
- type → String
-
Retriever type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited