RunsPort class abstract
Port for run record operations.
- Implementers
Constructors
- RunsPort()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRun(
String id) → Future< RunRecord?> - Get a run record by ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryRuns(
RunQuery query) → Future< List< RunRecord> > - Query runs.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeRun(
RunRecord record) → Future< void> - Write a run record.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited