SourceInfo class
Describes where a piece of evidence came from.
Constructors
Properties
-
attributes
→ Map<
String, dynamic> -
Additional source attributes (can include author, etc.).
final
- capturedAt → DateTime?
-
When the original was created/captured.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Source name/identifier (required for proper tracking).
final
- reliability → double?
-
Reliability score (0.0 to 1.0).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Source type description.
final
- uri → String?
-
Source URI.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited