StoragePort<T> class
abstract
Generic storage port for typed entities.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String id) → Future< void> - Delete an item.
-
exists(
String id) → Future< bool> - Check if item exists.
-
get(
String id) → Future< T?> - Get an item by ID.
-
getAll(
) → Future< List< T> > - Get all items.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Map< String, dynamic> criteria) → Future<List< T> > - Query items by criteria.
-
save(
String id, T item) → Future< void> - Save an item.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited