StubAnalysisFunctionPort class
Stub function port for testing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
executeFunction(
{required String functionName, required Map< String, dynamic> parameters, required AnalysisDataSet data}) → Future<AnalysisFunctionResult> -
Execute an analysis function on a data set.
override
-
getFunctionCatalog(
) → Future< List< AnalysisFunctionInfo> > -
List available functions with parameter schemas.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerFunction(
AnalysisFunctionInfo function) → Future< void> -
Register a new analysis function.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterFunction(
String functionName) → Future< void> -
Unregister a function.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited