StubMetricPort class
Stub metric port for testing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compute(
String metricName, Map< String, dynamic> context) → Future<MetricValue> -
Compute a metric value.
override
-
history(
String metricName, {DateTime? start, DateTime? end, int? limit}) → Future< List< MetricValue> > -
Get historical values.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
record(
String metricName, double value, {Map< String, String> ? tags}) → Future<void> -
Record a metric value.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
watch(
String metricName) → Stream< MetricEvent> -
Watch metric changes.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited