StubMetricsPort class
Stub implementation for testing.
- Implemented types
Constructors
- StubMetricsPort()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeMetric(
MetricSpec spec) → Future< MetricResult> -
Compute a metric on demand from a specification.
override
-
getMetric(
String name, String entityId, {Period? period}) → Future< MetricResult?> -
Retrieve a single metric for an entity over a period.
override
-
getMetrics(
List< String> names, String entityId, {Period? period}) → Future<Map< String, MetricResult> > -
Retrieve multiple metrics for an entity.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited