StubRunbookPort class
Stub implementation for testing.
- Implemented types
Constructors
- StubRunbookPort()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listRunbooks(
) → Future< List< RunbookDescriptor> > -
List available runbooks.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runRunbook(
String id, Map< String, dynamic> input) → Future<RunbookExecution> -
Execute a runbook.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited