StubUiPort class
Stub implementation of UiPort for testing.
Returns minimal valid responses for all operations.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromDefinition(
Map< String, dynamic> definitionJson) → Future<UiResult< UiWriteOutput> > -
Write: Convert UI definition JSON into bundle-compatible sections.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAppInfo(
McpBundle bundle) → Future< UiResult< Map< >String, dynamic> > -
Read: Extract lightweight app info for discovery/listing.
override
-
toDefinition(
McpBundle bundle) → Future< UiResult< Map< >String, dynamic> > -
Read: Convert McpBundle into runtime-consumable UI definition JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited