SubscriptionHandle class
Handle identifying an active subscription.
Constructors
- SubscriptionHandle({required String subscriptionId, required String topic, required TopicMode mode, required int createdAt, int? expiresAt})
-
const
-
SubscriptionHandle.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- createdAt → int
-
Creation timestamp in epoch milliseconds.
final
- expiresAt → int?
-
Expiration timestamp in epoch milliseconds, if TTL is set.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → TopicMode
-
Subscription mode (continuous, onChange, poll, event).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionId → String
-
Unique subscription identifier.
final
- topic → String
-
Topic URI this subscription is bound to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited