SubscriptionStatus class
Status information for an active subscription.
Constructors
Properties
- active → bool
-
Whether the subscription is currently active.
final
- bufferCapacity → int
-
Maximum buffer capacity in number of items.
final
- bufferUsed → int
-
Current buffer usage in number of items.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastMessageAt → DateTime?
-
Timestamp of the last delivered message, if any.
final
- messagesDelivered → int
-
Total number of messages successfully delivered.
final
- messagesDropped → int
-
Total number of messages dropped (e.g., due to backpressure).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionId → String
-
Subscription identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited