Tension class
Detected tension between Philosophy and another layer.
- Annotations
-
- @immutable
Constructors
-
Tension({required String id, required TensionSource source, required String philosophyDirective, required String opposingDirective, required TensionSeverity severity, required String description, List<
ResolutionOption> resolutionOptions = const [], String? ethosComponentId, DateTime? detectedAt}) -
Tension.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
Human-readable description.
final
- detectedAt → DateTime
-
When the tension was detected.
final
- ethosComponentId → String?
-
Which ethos component is involved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier.
final
- isCritical → bool
-
Whether this tension requires immediate resolution.
no setter
- isResolvable → bool
-
Whether this tension has available resolution options.
no setter
- opposingDirective → String
-
What the other layer says.
final
- philosophyDirective → String
-
What philosophy says.
final
-
resolutionOptions
→ List<
ResolutionOption> -
Possible resolutions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → TensionSeverity
-
How serious the conflict is.
final
- source → TensionSource
-
Which layers are in conflict.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited