ToolResult class
Tool execution result.
Constructors
- ToolResult({required dynamic content, bool isError = false, String? errorMessage})
-
const
- ToolResult.error(String message)
-
Create error result.
factory
- ToolResult.success(dynamic content)
-
Create success result.
factory
Properties
- content → dynamic
-
Result content.
final
- errorMessage → String?
-
Error message if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
Whether execution resulted in error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited