TypedPayload class
Typed payload with value, unit, timestamp, and quality.
Constructors
- TypedPayload({required PayloadType type, required dynamic value, String? unit, required DateTime timestamp, Quality quality = Quality.ok, PayloadSource? source})
-
TypedPayload.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- quality → Quality
-
Quality indicator for this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PayloadSource?
-
Source information for this payload.
final
- timestamp → DateTime
-
Timestamp when the value was captured.
final
- type → PayloadType
-
Data type of the value.
final
- unit → String?
-
Unit of measurement (e.g., 'celsius', 'rpm').
final
- value → dynamic
-
The actual payload value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited