UiSection class
UI section containing screens and widgets.
Constructors
-
UiSection({String schemaVersion = '1.0.0', List<
ScreenDefinition> screens = const [], Map<String, WidgetDefinition> widgets = const {}, ThemeConfig? theme, Map<String, StateDefinition> state = const {}}) -
const
-
UiSection.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Navigation configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
Schema version for UI section.
final
-
screens
→ List<
ScreenDefinition> -
List of screens in the application.
final
-
state
→ Map<
String, StateDefinition> -
Global UI state definitions.
final
- theme → ThemeConfig?
-
Theme configuration.
final
-
widgets
→ Map<
String, WidgetDefinition> -
Reusable widget definitions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited