ValueResolution class
Value conflict resolution result.
- Annotations
-
- @immutable
Constructors
- ValueResolution({required ValuePriority winner, ValuePriority? loser, required String rationale, bool contextDependent = false, String? appliedCondition})
-
const
-
ValueResolution.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appliedCondition → String?
-
Which condition triggered the shift.
final
- contextDependent → bool
-
Whether a conditional priority shift was applied.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loser → ValuePriority?
-
The losing value priority.
final
- rationale → String
-
Why this resolution was chosen.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- winner → ValuePriority
-
The winning value priority.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited