CelmEscalated class
Suspended. The run keeps its id, budget, history and evidence, and a planner's answer names where to continue from.
- Inheritance
-
- Object
- CelmOutcome
- CelmEscalated
Constructors
-
CelmEscalated(String runId, {required CelmEscalationReason reason, required CelmDigest digest, required String blockedAt, required CelmBudgetUse budget, List<
CelmAttempt> history = const []}) -
const
Properties
- blockedAt → String
-
final
- budget → CelmBudgetUse
-
final
- digest → CelmDigest
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
CelmAttempt> -
final
- reason → CelmEscalationReason
-
final
- runId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited