ChannelCapabilities class

Capabilities of a channel implementation.

Constructors

ChannelCapabilities({bool text = true, bool richMessages = false, bool attachments = false, bool reactions = false, bool threads = false, bool editing = false, bool deleting = false, bool typingIndicator = false, int? maxMessageLength})
const
ChannelCapabilities.fromJson(Map<String, dynamic> json)
Create from JSON.
factory
ChannelCapabilities.full()
Full-featured channel.
const
ChannelCapabilities.textOnly()
Text-only channel.
const

Properties

attachments bool
Whether file attachments are supported.
final
deleting bool
Whether deleting sent messages is supported.
final
editing bool
Whether editing sent messages is supported.
final
hashCode int
The hash code for this object.
no setterinherited
maxMessageLength int?
Maximum message length (null = unlimited).
final
reactions bool
Whether reactions are supported.
final
richMessages bool
Whether rich/block messages are supported.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text bool
Whether text messages are supported.
final
threads bool
Whether threads are supported.
final
typingIndicator bool
Whether typing indicators are supported.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited