ChannelPort class abstract
Abstract port for bidirectional channel communication.
Implementations:
- mcp_channel: SlackChannelPort, TelegramChannelPort, DiscordChannelPort
- mcp_server: HttpChannelPort, WebSocketChannelPort, StdioChannelPort
- mcp_client: HttpClientChannelPort, WebSocketClientChannelPort
- Implementers
Constructors
Properties
- capabilities → ChannelCapabilities
-
Capabilities of this channel.
no setter
-
events
→ Stream<
ChannelEvent> -
Stream of incoming events.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → ChannelIdentity
-
Channel identity.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String messageId) → Future< void> - Delete a previously sent message (if supported).
-
edit(
String messageId, ChannelResponse response) → Future< void> - Edit a previously sent message (if supported).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
react(
String messageId, String reaction) → Future< void> - Add a reaction to a message (if supported).
-
send(
ChannelResponse response) → Future< void> - Send a response to the channel.
-
sendTyping(
ConversationKey conversation) → Future< void> - Send typing indicator (if supported).
-
start(
) → Future< void> - Start receiving events.
-
stop(
) → Future< void> - Stop receiving events.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited